""" Contains all the data models used in inputs/outputs """

from .delete_by_org_api_key_by_id_response_200 import DeleteByOrgApiKeyByIdResponse200
from .delete_by_org_api_key_by_id_response_400 import DeleteByOrgApiKeyByIdResponse400
from .delete_by_org_api_key_by_id_response_400_error import DeleteByOrgApiKeyByIdResponse400Error
from .delete_by_org_api_key_by_id_response_400_error_details import DeleteByOrgApiKeyByIdResponse400ErrorDetails
from .delete_by_org_api_key_by_id_response_401 import DeleteByOrgApiKeyByIdResponse401
from .delete_by_org_api_key_by_id_response_401_error import DeleteByOrgApiKeyByIdResponse401Error
from .delete_by_org_api_key_by_id_response_401_error_details import DeleteByOrgApiKeyByIdResponse401ErrorDetails
from .delete_by_org_api_key_by_id_response_403 import DeleteByOrgApiKeyByIdResponse403
from .delete_by_org_api_key_by_id_response_403_error import DeleteByOrgApiKeyByIdResponse403Error
from .delete_by_org_api_key_by_id_response_403_error_details import DeleteByOrgApiKeyByIdResponse403ErrorDetails
from .delete_by_org_api_key_by_id_response_404 import DeleteByOrgApiKeyByIdResponse404
from .delete_by_org_api_key_by_id_response_404_error import DeleteByOrgApiKeyByIdResponse404Error
from .delete_by_org_api_key_by_id_response_404_error_details import DeleteByOrgApiKeyByIdResponse404ErrorDetails
from .delete_by_org_api_key_by_id_response_406 import DeleteByOrgApiKeyByIdResponse406
from .delete_by_org_api_key_by_id_response_406_error import DeleteByOrgApiKeyByIdResponse406Error
from .delete_by_org_api_key_by_id_response_406_error_details import DeleteByOrgApiKeyByIdResponse406ErrorDetails
from .delete_by_org_api_key_by_id_response_409 import DeleteByOrgApiKeyByIdResponse409
from .delete_by_org_api_key_by_id_response_409_error import DeleteByOrgApiKeyByIdResponse409Error
from .delete_by_org_api_key_by_id_response_409_error_details import DeleteByOrgApiKeyByIdResponse409ErrorDetails
from .delete_by_org_api_key_by_id_response_500 import DeleteByOrgApiKeyByIdResponse500
from .delete_by_org_api_key_by_id_response_500_error import DeleteByOrgApiKeyByIdResponse500Error
from .delete_by_org_api_key_by_id_response_500_error_details import DeleteByOrgApiKeyByIdResponse500ErrorDetails
from .delete_by_org_by_repo_branch_by_branch_response_200 import DeleteByOrgByRepoBranchByBranchResponse200
from .delete_by_org_by_repo_branch_by_branch_response_400 import DeleteByOrgByRepoBranchByBranchResponse400
from .delete_by_org_by_repo_branch_by_branch_response_400_error import DeleteByOrgByRepoBranchByBranchResponse400Error
from .delete_by_org_by_repo_branch_by_branch_response_400_error_details import DeleteByOrgByRepoBranchByBranchResponse400ErrorDetails
from .delete_by_org_by_repo_branch_by_branch_response_401 import DeleteByOrgByRepoBranchByBranchResponse401
from .delete_by_org_by_repo_branch_by_branch_response_401_error import DeleteByOrgByRepoBranchByBranchResponse401Error
from .delete_by_org_by_repo_branch_by_branch_response_401_error_details import DeleteByOrgByRepoBranchByBranchResponse401ErrorDetails
from .delete_by_org_by_repo_branch_by_branch_response_403 import DeleteByOrgByRepoBranchByBranchResponse403
from .delete_by_org_by_repo_branch_by_branch_response_403_error import DeleteByOrgByRepoBranchByBranchResponse403Error
from .delete_by_org_by_repo_branch_by_branch_response_403_error_details import DeleteByOrgByRepoBranchByBranchResponse403ErrorDetails
from .delete_by_org_by_repo_branch_by_branch_response_404 import DeleteByOrgByRepoBranchByBranchResponse404
from .delete_by_org_by_repo_branch_by_branch_response_404_error import DeleteByOrgByRepoBranchByBranchResponse404Error
from .delete_by_org_by_repo_branch_by_branch_response_404_error_details import DeleteByOrgByRepoBranchByBranchResponse404ErrorDetails
from .delete_by_org_by_repo_branch_by_branch_response_406 import DeleteByOrgByRepoBranchByBranchResponse406
from .delete_by_org_by_repo_branch_by_branch_response_406_error import DeleteByOrgByRepoBranchByBranchResponse406Error
from .delete_by_org_by_repo_branch_by_branch_response_406_error_details import DeleteByOrgByRepoBranchByBranchResponse406ErrorDetails
from .delete_by_org_by_repo_branch_by_branch_response_409 import DeleteByOrgByRepoBranchByBranchResponse409
from .delete_by_org_by_repo_branch_by_branch_response_409_error import DeleteByOrgByRepoBranchByBranchResponse409Error
from .delete_by_org_by_repo_branch_by_branch_response_409_error_details import DeleteByOrgByRepoBranchByBranchResponse409ErrorDetails
from .delete_by_org_by_repo_branch_by_branch_response_500 import DeleteByOrgByRepoBranchByBranchResponse500
from .delete_by_org_by_repo_branch_by_branch_response_500_error import DeleteByOrgByRepoBranchByBranchResponse500Error
from .delete_by_org_by_repo_branch_by_branch_response_500_error_details import DeleteByOrgByRepoBranchByBranchResponse500ErrorDetails
from .delete_by_org_by_repo_response_200 import DeleteByOrgByRepoResponse200
from .delete_by_org_by_repo_response_400 import DeleteByOrgByRepoResponse400
from .delete_by_org_by_repo_response_400_error import DeleteByOrgByRepoResponse400Error
from .delete_by_org_by_repo_response_400_error_details import DeleteByOrgByRepoResponse400ErrorDetails
from .delete_by_org_by_repo_response_401 import DeleteByOrgByRepoResponse401
from .delete_by_org_by_repo_response_401_error import DeleteByOrgByRepoResponse401Error
from .delete_by_org_by_repo_response_401_error_details import DeleteByOrgByRepoResponse401ErrorDetails
from .delete_by_org_by_repo_response_403 import DeleteByOrgByRepoResponse403
from .delete_by_org_by_repo_response_403_error import DeleteByOrgByRepoResponse403Error
from .delete_by_org_by_repo_response_403_error_details import DeleteByOrgByRepoResponse403ErrorDetails
from .delete_by_org_by_repo_response_404 import DeleteByOrgByRepoResponse404
from .delete_by_org_by_repo_response_404_error import DeleteByOrgByRepoResponse404Error
from .delete_by_org_by_repo_response_404_error_details import DeleteByOrgByRepoResponse404ErrorDetails
from .delete_by_org_by_repo_response_406 import DeleteByOrgByRepoResponse406
from .delete_by_org_by_repo_response_406_error import DeleteByOrgByRepoResponse406Error
from .delete_by_org_by_repo_response_406_error_details import DeleteByOrgByRepoResponse406ErrorDetails
from .delete_by_org_by_repo_response_409 import DeleteByOrgByRepoResponse409
from .delete_by_org_by_repo_response_409_error import DeleteByOrgByRepoResponse409Error
from .delete_by_org_by_repo_response_409_error_details import DeleteByOrgByRepoResponse409ErrorDetails
from .delete_by_org_by_repo_response_500 import DeleteByOrgByRepoResponse500
from .delete_by_org_by_repo_response_500_error import DeleteByOrgByRepoResponse500Error
from .delete_by_org_by_repo_response_500_error_details import DeleteByOrgByRepoResponse500ErrorDetails
from .delete_by_org_by_repo_webhook_by_webhook_id_response_200 import DeleteByOrgByRepoWebhookByWebhookIdResponse200
from .delete_by_org_by_repo_webhook_by_webhook_id_response_400 import DeleteByOrgByRepoWebhookByWebhookIdResponse400
from .delete_by_org_by_repo_webhook_by_webhook_id_response_400_error import DeleteByOrgByRepoWebhookByWebhookIdResponse400Error
from .delete_by_org_by_repo_webhook_by_webhook_id_response_400_error_details import DeleteByOrgByRepoWebhookByWebhookIdResponse400ErrorDetails
from .delete_by_org_by_repo_webhook_by_webhook_id_response_401 import DeleteByOrgByRepoWebhookByWebhookIdResponse401
from .delete_by_org_by_repo_webhook_by_webhook_id_response_401_error import DeleteByOrgByRepoWebhookByWebhookIdResponse401Error
from .delete_by_org_by_repo_webhook_by_webhook_id_response_401_error_details import DeleteByOrgByRepoWebhookByWebhookIdResponse401ErrorDetails
from .delete_by_org_by_repo_webhook_by_webhook_id_response_403 import DeleteByOrgByRepoWebhookByWebhookIdResponse403
from .delete_by_org_by_repo_webhook_by_webhook_id_response_403_error import DeleteByOrgByRepoWebhookByWebhookIdResponse403Error
from .delete_by_org_by_repo_webhook_by_webhook_id_response_403_error_details import DeleteByOrgByRepoWebhookByWebhookIdResponse403ErrorDetails
from .delete_by_org_by_repo_webhook_by_webhook_id_response_404 import DeleteByOrgByRepoWebhookByWebhookIdResponse404
from .delete_by_org_by_repo_webhook_by_webhook_id_response_404_error import DeleteByOrgByRepoWebhookByWebhookIdResponse404Error
from .delete_by_org_by_repo_webhook_by_webhook_id_response_404_error_details import DeleteByOrgByRepoWebhookByWebhookIdResponse404ErrorDetails
from .delete_by_org_by_repo_webhook_by_webhook_id_response_406 import DeleteByOrgByRepoWebhookByWebhookIdResponse406
from .delete_by_org_by_repo_webhook_by_webhook_id_response_406_error import DeleteByOrgByRepoWebhookByWebhookIdResponse406Error
from .delete_by_org_by_repo_webhook_by_webhook_id_response_406_error_details import DeleteByOrgByRepoWebhookByWebhookIdResponse406ErrorDetails
from .delete_by_org_by_repo_webhook_by_webhook_id_response_409 import DeleteByOrgByRepoWebhookByWebhookIdResponse409
from .delete_by_org_by_repo_webhook_by_webhook_id_response_409_error import DeleteByOrgByRepoWebhookByWebhookIdResponse409Error
from .delete_by_org_by_repo_webhook_by_webhook_id_response_409_error_details import DeleteByOrgByRepoWebhookByWebhookIdResponse409ErrorDetails
from .delete_by_org_by_repo_webhook_by_webhook_id_response_500 import DeleteByOrgByRepoWebhookByWebhookIdResponse500
from .delete_by_org_by_repo_webhook_by_webhook_id_response_500_error import DeleteByOrgByRepoWebhookByWebhookIdResponse500Error
from .delete_by_org_by_repo_webhook_by_webhook_id_response_500_error_details import DeleteByOrgByRepoWebhookByWebhookIdResponse500ErrorDetails
from .get_by_org_api_key_response_200 import GetByOrgApiKeyResponse200
from .get_by_org_api_key_response_200_api_keys_item import GetByOrgApiKeyResponse200ApiKeysItem
from .get_by_org_api_key_response_400 import GetByOrgApiKeyResponse400
from .get_by_org_api_key_response_400_error import GetByOrgApiKeyResponse400Error
from .get_by_org_api_key_response_400_error_details import GetByOrgApiKeyResponse400ErrorDetails
from .get_by_org_api_key_response_401 import GetByOrgApiKeyResponse401
from .get_by_org_api_key_response_401_error import GetByOrgApiKeyResponse401Error
from .get_by_org_api_key_response_401_error_details import GetByOrgApiKeyResponse401ErrorDetails
from .get_by_org_api_key_response_403 import GetByOrgApiKeyResponse403
from .get_by_org_api_key_response_403_error import GetByOrgApiKeyResponse403Error
from .get_by_org_api_key_response_403_error_details import GetByOrgApiKeyResponse403ErrorDetails
from .get_by_org_api_key_response_404 import GetByOrgApiKeyResponse404
from .get_by_org_api_key_response_404_error import GetByOrgApiKeyResponse404Error
from .get_by_org_api_key_response_404_error_details import GetByOrgApiKeyResponse404ErrorDetails
from .get_by_org_api_key_response_406 import GetByOrgApiKeyResponse406
from .get_by_org_api_key_response_406_error import GetByOrgApiKeyResponse406Error
from .get_by_org_api_key_response_406_error_details import GetByOrgApiKeyResponse406ErrorDetails
from .get_by_org_api_key_response_409 import GetByOrgApiKeyResponse409
from .get_by_org_api_key_response_409_error import GetByOrgApiKeyResponse409Error
from .get_by_org_api_key_response_409_error_details import GetByOrgApiKeyResponse409ErrorDetails
from .get_by_org_api_key_response_500 import GetByOrgApiKeyResponse500
from .get_by_org_api_key_response_500_error import GetByOrgApiKeyResponse500Error
from .get_by_org_api_key_response_500_error_details import GetByOrgApiKeyResponse500ErrorDetails
from .get_by_org_by_repo_branch_response_200 import GetByOrgByRepoBranchResponse200
from .get_by_org_by_repo_branch_response_200_branches_item import GetByOrgByRepoBranchResponse200BranchesItem
from .get_by_org_by_repo_branch_response_400 import GetByOrgByRepoBranchResponse400
from .get_by_org_by_repo_branch_response_400_error import GetByOrgByRepoBranchResponse400Error
from .get_by_org_by_repo_branch_response_400_error_details import GetByOrgByRepoBranchResponse400ErrorDetails
from .get_by_org_by_repo_branch_response_401 import GetByOrgByRepoBranchResponse401
from .get_by_org_by_repo_branch_response_401_error import GetByOrgByRepoBranchResponse401Error
from .get_by_org_by_repo_branch_response_401_error_details import GetByOrgByRepoBranchResponse401ErrorDetails
from .get_by_org_by_repo_branch_response_403 import GetByOrgByRepoBranchResponse403
from .get_by_org_by_repo_branch_response_403_error import GetByOrgByRepoBranchResponse403Error
from .get_by_org_by_repo_branch_response_403_error_details import GetByOrgByRepoBranchResponse403ErrorDetails
from .get_by_org_by_repo_branch_response_404 import GetByOrgByRepoBranchResponse404
from .get_by_org_by_repo_branch_response_404_error import GetByOrgByRepoBranchResponse404Error
from .get_by_org_by_repo_branch_response_404_error_details import GetByOrgByRepoBranchResponse404ErrorDetails
from .get_by_org_by_repo_branch_response_406 import GetByOrgByRepoBranchResponse406
from .get_by_org_by_repo_branch_response_406_error import GetByOrgByRepoBranchResponse406Error
from .get_by_org_by_repo_branch_response_406_error_details import GetByOrgByRepoBranchResponse406ErrorDetails
from .get_by_org_by_repo_branch_response_409 import GetByOrgByRepoBranchResponse409
from .get_by_org_by_repo_branch_response_409_error import GetByOrgByRepoBranchResponse409Error
from .get_by_org_by_repo_branch_response_409_error_details import GetByOrgByRepoBranchResponse409ErrorDetails
from .get_by_org_by_repo_branch_response_500 import GetByOrgByRepoBranchResponse500
from .get_by_org_by_repo_branch_response_500_error import GetByOrgByRepoBranchResponse500Error
from .get_by_org_by_repo_branch_response_500_error_details import GetByOrgByRepoBranchResponse500ErrorDetails
from .get_by_org_by_repo_commit_by_sha_response_200 import GetByOrgByRepoCommitByShaResponse200
from .get_by_org_by_repo_commit_by_sha_response_200_author import GetByOrgByRepoCommitByShaResponse200Author
from .get_by_org_by_repo_commit_by_sha_response_200_committer import GetByOrgByRepoCommitByShaResponse200Committer
from .get_by_org_by_repo_commit_by_sha_response_400 import GetByOrgByRepoCommitByShaResponse400
from .get_by_org_by_repo_commit_by_sha_response_400_error import GetByOrgByRepoCommitByShaResponse400Error
from .get_by_org_by_repo_commit_by_sha_response_400_error_details import GetByOrgByRepoCommitByShaResponse400ErrorDetails
from .get_by_org_by_repo_commit_by_sha_response_401 import GetByOrgByRepoCommitByShaResponse401
from .get_by_org_by_repo_commit_by_sha_response_401_error import GetByOrgByRepoCommitByShaResponse401Error
from .get_by_org_by_repo_commit_by_sha_response_401_error_details import GetByOrgByRepoCommitByShaResponse401ErrorDetails
from .get_by_org_by_repo_commit_by_sha_response_403 import GetByOrgByRepoCommitByShaResponse403
from .get_by_org_by_repo_commit_by_sha_response_403_error import GetByOrgByRepoCommitByShaResponse403Error
from .get_by_org_by_repo_commit_by_sha_response_403_error_details import GetByOrgByRepoCommitByShaResponse403ErrorDetails
from .get_by_org_by_repo_commit_by_sha_response_404 import GetByOrgByRepoCommitByShaResponse404
from .get_by_org_by_repo_commit_by_sha_response_404_error import GetByOrgByRepoCommitByShaResponse404Error
from .get_by_org_by_repo_commit_by_sha_response_404_error_details import GetByOrgByRepoCommitByShaResponse404ErrorDetails
from .get_by_org_by_repo_commit_by_sha_response_406 import GetByOrgByRepoCommitByShaResponse406
from .get_by_org_by_repo_commit_by_sha_response_406_error import GetByOrgByRepoCommitByShaResponse406Error
from .get_by_org_by_repo_commit_by_sha_response_406_error_details import GetByOrgByRepoCommitByShaResponse406ErrorDetails
from .get_by_org_by_repo_commit_by_sha_response_409 import GetByOrgByRepoCommitByShaResponse409
from .get_by_org_by_repo_commit_by_sha_response_409_error import GetByOrgByRepoCommitByShaResponse409Error
from .get_by_org_by_repo_commit_by_sha_response_409_error_details import GetByOrgByRepoCommitByShaResponse409ErrorDetails
from .get_by_org_by_repo_commit_by_sha_response_500 import GetByOrgByRepoCommitByShaResponse500
from .get_by_org_by_repo_commit_by_sha_response_500_error import GetByOrgByRepoCommitByShaResponse500Error
from .get_by_org_by_repo_commit_by_sha_response_500_error_details import GetByOrgByRepoCommitByShaResponse500ErrorDetails
from .get_by_org_by_repo_commit_response_200 import GetByOrgByRepoCommitResponse200
from .get_by_org_by_repo_commit_response_200_commits_item import GetByOrgByRepoCommitResponse200CommitsItem
from .get_by_org_by_repo_commit_response_200_commits_item_author import GetByOrgByRepoCommitResponse200CommitsItemAuthor
from .get_by_org_by_repo_commit_response_200_commits_item_committer import GetByOrgByRepoCommitResponse200CommitsItemCommitter
from .get_by_org_by_repo_commit_response_400 import GetByOrgByRepoCommitResponse400
from .get_by_org_by_repo_commit_response_400_error import GetByOrgByRepoCommitResponse400Error
from .get_by_org_by_repo_commit_response_400_error_details import GetByOrgByRepoCommitResponse400ErrorDetails
from .get_by_org_by_repo_commit_response_401 import GetByOrgByRepoCommitResponse401
from .get_by_org_by_repo_commit_response_401_error import GetByOrgByRepoCommitResponse401Error
from .get_by_org_by_repo_commit_response_401_error_details import GetByOrgByRepoCommitResponse401ErrorDetails
from .get_by_org_by_repo_commit_response_403 import GetByOrgByRepoCommitResponse403
from .get_by_org_by_repo_commit_response_403_error import GetByOrgByRepoCommitResponse403Error
from .get_by_org_by_repo_commit_response_403_error_details import GetByOrgByRepoCommitResponse403ErrorDetails
from .get_by_org_by_repo_commit_response_404 import GetByOrgByRepoCommitResponse404
from .get_by_org_by_repo_commit_response_404_error import GetByOrgByRepoCommitResponse404Error
from .get_by_org_by_repo_commit_response_404_error_details import GetByOrgByRepoCommitResponse404ErrorDetails
from .get_by_org_by_repo_commit_response_406 import GetByOrgByRepoCommitResponse406
from .get_by_org_by_repo_commit_response_406_error import GetByOrgByRepoCommitResponse406Error
from .get_by_org_by_repo_commit_response_406_error_details import GetByOrgByRepoCommitResponse406ErrorDetails
from .get_by_org_by_repo_commit_response_409 import GetByOrgByRepoCommitResponse409
from .get_by_org_by_repo_commit_response_409_error import GetByOrgByRepoCommitResponse409Error
from .get_by_org_by_repo_commit_response_409_error_details import GetByOrgByRepoCommitResponse409ErrorDetails
from .get_by_org_by_repo_commit_response_500 import GetByOrgByRepoCommitResponse500
from .get_by_org_by_repo_commit_response_500_error import GetByOrgByRepoCommitResponse500Error
from .get_by_org_by_repo_commit_response_500_error_details import GetByOrgByRepoCommitResponse500ErrorDetails
from .get_by_org_by_repo_content_response_200_type_0 import GetByOrgByRepoContentResponse200Type0
from .get_by_org_by_repo_content_response_200_type_1 import GetByOrgByRepoContentResponse200Type1
from .get_by_org_by_repo_content_response_200_type_2 import GetByOrgByRepoContentResponse200Type2
from .get_by_org_by_repo_content_response_200_type_2_entries_item_type_0 import GetByOrgByRepoContentResponse200Type2EntriesItemType0
from .get_by_org_by_repo_content_response_200_type_2_entries_item_type_1 import GetByOrgByRepoContentResponse200Type2EntriesItemType1
from .get_by_org_by_repo_content_response_200_type_2_entries_item_type_2 import GetByOrgByRepoContentResponse200Type2EntriesItemType2
from .get_by_org_by_repo_content_response_400 import GetByOrgByRepoContentResponse400
from .get_by_org_by_repo_content_response_400_error import GetByOrgByRepoContentResponse400Error
from .get_by_org_by_repo_content_response_400_error_details import GetByOrgByRepoContentResponse400ErrorDetails
from .get_by_org_by_repo_content_response_401 import GetByOrgByRepoContentResponse401
from .get_by_org_by_repo_content_response_401_error import GetByOrgByRepoContentResponse401Error
from .get_by_org_by_repo_content_response_401_error_details import GetByOrgByRepoContentResponse401ErrorDetails
from .get_by_org_by_repo_content_response_403 import GetByOrgByRepoContentResponse403
from .get_by_org_by_repo_content_response_403_error import GetByOrgByRepoContentResponse403Error
from .get_by_org_by_repo_content_response_403_error_details import GetByOrgByRepoContentResponse403ErrorDetails
from .get_by_org_by_repo_content_response_404 import GetByOrgByRepoContentResponse404
from .get_by_org_by_repo_content_response_404_error import GetByOrgByRepoContentResponse404Error
from .get_by_org_by_repo_content_response_404_error_details import GetByOrgByRepoContentResponse404ErrorDetails
from .get_by_org_by_repo_content_response_406 import GetByOrgByRepoContentResponse406
from .get_by_org_by_repo_content_response_406_error import GetByOrgByRepoContentResponse406Error
from .get_by_org_by_repo_content_response_406_error_details import GetByOrgByRepoContentResponse406ErrorDetails
from .get_by_org_by_repo_content_response_409 import GetByOrgByRepoContentResponse409
from .get_by_org_by_repo_content_response_409_error import GetByOrgByRepoContentResponse409Error
from .get_by_org_by_repo_content_response_409_error_details import GetByOrgByRepoContentResponse409ErrorDetails
from .get_by_org_by_repo_content_response_500 import GetByOrgByRepoContentResponse500
from .get_by_org_by_repo_content_response_500_error import GetByOrgByRepoContentResponse500Error
from .get_by_org_by_repo_content_response_500_error_details import GetByOrgByRepoContentResponse500ErrorDetails
from .get_by_org_by_repo_diff_response_200 import GetByOrgByRepoDiffResponse200
from .get_by_org_by_repo_diff_response_200_files_item import GetByOrgByRepoDiffResponse200FilesItem
from .get_by_org_by_repo_diff_response_200_files_item_status import GetByOrgByRepoDiffResponse200FilesItemStatus
from .get_by_org_by_repo_diff_response_200_filtered_files_item import GetByOrgByRepoDiffResponse200FilteredFilesItem
from .get_by_org_by_repo_diff_response_200_filtered_files_item_status import GetByOrgByRepoDiffResponse200FilteredFilesItemStatus
from .get_by_org_by_repo_diff_response_200_stats import GetByOrgByRepoDiffResponse200Stats
from .get_by_org_by_repo_diff_response_400 import GetByOrgByRepoDiffResponse400
from .get_by_org_by_repo_diff_response_400_error import GetByOrgByRepoDiffResponse400Error
from .get_by_org_by_repo_diff_response_400_error_details import GetByOrgByRepoDiffResponse400ErrorDetails
from .get_by_org_by_repo_diff_response_401 import GetByOrgByRepoDiffResponse401
from .get_by_org_by_repo_diff_response_401_error import GetByOrgByRepoDiffResponse401Error
from .get_by_org_by_repo_diff_response_401_error_details import GetByOrgByRepoDiffResponse401ErrorDetails
from .get_by_org_by_repo_diff_response_403 import GetByOrgByRepoDiffResponse403
from .get_by_org_by_repo_diff_response_403_error import GetByOrgByRepoDiffResponse403Error
from .get_by_org_by_repo_diff_response_403_error_details import GetByOrgByRepoDiffResponse403ErrorDetails
from .get_by_org_by_repo_diff_response_404 import GetByOrgByRepoDiffResponse404
from .get_by_org_by_repo_diff_response_404_error import GetByOrgByRepoDiffResponse404Error
from .get_by_org_by_repo_diff_response_404_error_details import GetByOrgByRepoDiffResponse404ErrorDetails
from .get_by_org_by_repo_diff_response_406 import GetByOrgByRepoDiffResponse406
from .get_by_org_by_repo_diff_response_406_error import GetByOrgByRepoDiffResponse406Error
from .get_by_org_by_repo_diff_response_406_error_details import GetByOrgByRepoDiffResponse406ErrorDetails
from .get_by_org_by_repo_diff_response_409 import GetByOrgByRepoDiffResponse409
from .get_by_org_by_repo_diff_response_409_error import GetByOrgByRepoDiffResponse409Error
from .get_by_org_by_repo_diff_response_409_error_details import GetByOrgByRepoDiffResponse409ErrorDetails
from .get_by_org_by_repo_diff_response_500 import GetByOrgByRepoDiffResponse500
from .get_by_org_by_repo_diff_response_500_error import GetByOrgByRepoDiffResponse500Error
from .get_by_org_by_repo_diff_response_500_error_details import GetByOrgByRepoDiffResponse500ErrorDetails
from .get_by_org_by_repo_response_200 import GetByOrgByRepoResponse200
from .get_by_org_by_repo_response_200_tags import GetByOrgByRepoResponse200Tags
from .get_by_org_by_repo_response_200_upstream_type_0 import GetByOrgByRepoResponse200UpstreamType0
from .get_by_org_by_repo_response_200_upstream_type_0_autosync_type_0 import GetByOrgByRepoResponse200UpstreamType0AutosyncType0
from .get_by_org_by_repo_response_200_upstream_type_0_autosync_type_0_resolution_strategy import GetByOrgByRepoResponse200UpstreamType0AutosyncType0ResolutionStrategy
from .get_by_org_by_repo_response_400 import GetByOrgByRepoResponse400
from .get_by_org_by_repo_response_400_error import GetByOrgByRepoResponse400Error
from .get_by_org_by_repo_response_400_error_details import GetByOrgByRepoResponse400ErrorDetails
from .get_by_org_by_repo_response_401 import GetByOrgByRepoResponse401
from .get_by_org_by_repo_response_401_error import GetByOrgByRepoResponse401Error
from .get_by_org_by_repo_response_401_error_details import GetByOrgByRepoResponse401ErrorDetails
from .get_by_org_by_repo_response_403 import GetByOrgByRepoResponse403
from .get_by_org_by_repo_response_403_error import GetByOrgByRepoResponse403Error
from .get_by_org_by_repo_response_403_error_details import GetByOrgByRepoResponse403ErrorDetails
from .get_by_org_by_repo_response_404 import GetByOrgByRepoResponse404
from .get_by_org_by_repo_response_404_error import GetByOrgByRepoResponse404Error
from .get_by_org_by_repo_response_404_error_details import GetByOrgByRepoResponse404ErrorDetails
from .get_by_org_by_repo_response_406 import GetByOrgByRepoResponse406
from .get_by_org_by_repo_response_406_error import GetByOrgByRepoResponse406Error
from .get_by_org_by_repo_response_406_error_details import GetByOrgByRepoResponse406ErrorDetails
from .get_by_org_by_repo_response_409 import GetByOrgByRepoResponse409
from .get_by_org_by_repo_response_409_error import GetByOrgByRepoResponse409Error
from .get_by_org_by_repo_response_409_error_details import GetByOrgByRepoResponse409ErrorDetails
from .get_by_org_by_repo_response_500 import GetByOrgByRepoResponse500
from .get_by_org_by_repo_response_500_error import GetByOrgByRepoResponse500Error
from .get_by_org_by_repo_response_500_error_details import GetByOrgByRepoResponse500ErrorDetails
from .get_by_org_by_repo_webhook_response_200 import GetByOrgByRepoWebhookResponse200
from .get_by_org_by_repo_webhook_response_200_webhooks_item import GetByOrgByRepoWebhookResponse200WebhooksItem
from .get_by_org_by_repo_webhook_response_200_webhooks_item_events_item import GetByOrgByRepoWebhookResponse200WebhooksItemEventsItem
from .get_by_org_by_repo_webhook_response_400 import GetByOrgByRepoWebhookResponse400
from .get_by_org_by_repo_webhook_response_400_error import GetByOrgByRepoWebhookResponse400Error
from .get_by_org_by_repo_webhook_response_400_error_details import GetByOrgByRepoWebhookResponse400ErrorDetails
from .get_by_org_by_repo_webhook_response_401 import GetByOrgByRepoWebhookResponse401
from .get_by_org_by_repo_webhook_response_401_error import GetByOrgByRepoWebhookResponse401Error
from .get_by_org_by_repo_webhook_response_401_error_details import GetByOrgByRepoWebhookResponse401ErrorDetails
from .get_by_org_by_repo_webhook_response_403 import GetByOrgByRepoWebhookResponse403
from .get_by_org_by_repo_webhook_response_403_error import GetByOrgByRepoWebhookResponse403Error
from .get_by_org_by_repo_webhook_response_403_error_details import GetByOrgByRepoWebhookResponse403ErrorDetails
from .get_by_org_by_repo_webhook_response_404 import GetByOrgByRepoWebhookResponse404
from .get_by_org_by_repo_webhook_response_404_error import GetByOrgByRepoWebhookResponse404Error
from .get_by_org_by_repo_webhook_response_404_error_details import GetByOrgByRepoWebhookResponse404ErrorDetails
from .get_by_org_by_repo_webhook_response_406 import GetByOrgByRepoWebhookResponse406
from .get_by_org_by_repo_webhook_response_406_error import GetByOrgByRepoWebhookResponse406Error
from .get_by_org_by_repo_webhook_response_406_error_details import GetByOrgByRepoWebhookResponse406ErrorDetails
from .get_by_org_by_repo_webhook_response_409 import GetByOrgByRepoWebhookResponse409
from .get_by_org_by_repo_webhook_response_409_error import GetByOrgByRepoWebhookResponse409Error
from .get_by_org_by_repo_webhook_response_409_error_details import GetByOrgByRepoWebhookResponse409ErrorDetails
from .get_by_org_by_repo_webhook_response_500 import GetByOrgByRepoWebhookResponse500
from .get_by_org_by_repo_webhook_response_500_error import GetByOrgByRepoWebhookResponse500Error
from .get_by_org_by_repo_webhook_response_500_error_details import GetByOrgByRepoWebhookResponse500ErrorDetails
from .get_by_org_repo_response_200 import GetByOrgRepoResponse200
from .get_by_org_repo_response_200_repos_item import GetByOrgRepoResponse200ReposItem
from .get_by_org_repo_response_200_repos_item_tags import GetByOrgRepoResponse200ReposItemTags
from .get_by_org_repo_response_200_repos_item_upstream_type_0 import GetByOrgRepoResponse200ReposItemUpstreamType0
from .get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0 import GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0
from .get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0_resolution_strategy import GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0ResolutionStrategy
from .get_by_org_repo_response_400 import GetByOrgRepoResponse400
from .get_by_org_repo_response_400_error import GetByOrgRepoResponse400Error
from .get_by_org_repo_response_400_error_details import GetByOrgRepoResponse400ErrorDetails
from .get_by_org_repo_response_401 import GetByOrgRepoResponse401
from .get_by_org_repo_response_401_error import GetByOrgRepoResponse401Error
from .get_by_org_repo_response_401_error_details import GetByOrgRepoResponse401ErrorDetails
from .get_by_org_repo_response_403 import GetByOrgRepoResponse403
from .get_by_org_repo_response_403_error import GetByOrgRepoResponse403Error
from .get_by_org_repo_response_403_error_details import GetByOrgRepoResponse403ErrorDetails
from .get_by_org_repo_response_404 import GetByOrgRepoResponse404
from .get_by_org_repo_response_404_error import GetByOrgRepoResponse404Error
from .get_by_org_repo_response_404_error_details import GetByOrgRepoResponse404ErrorDetails
from .get_by_org_repo_response_406 import GetByOrgRepoResponse406
from .get_by_org_repo_response_406_error import GetByOrgRepoResponse406Error
from .get_by_org_repo_response_406_error_details import GetByOrgRepoResponse406ErrorDetails
from .get_by_org_repo_response_409 import GetByOrgRepoResponse409
from .get_by_org_repo_response_409_error import GetByOrgRepoResponse409Error
from .get_by_org_repo_response_409_error_details import GetByOrgRepoResponse409ErrorDetails
from .get_by_org_repo_response_500 import GetByOrgRepoResponse500
from .get_by_org_repo_response_500_error import GetByOrgRepoResponse500Error
from .get_by_org_repo_response_500_error_details import GetByOrgRepoResponse500ErrorDetails
from .get_by_org_repo_tags_response_200 import GetByOrgRepoTagsResponse200
from .get_by_org_repo_tags_response_200_tags import GetByOrgRepoTagsResponse200Tags
from .get_by_org_repo_tags_response_200_tags_additional_property_item import GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem
from .get_by_org_repo_tags_response_400 import GetByOrgRepoTagsResponse400
from .get_by_org_repo_tags_response_400_error import GetByOrgRepoTagsResponse400Error
from .get_by_org_repo_tags_response_400_error_details import GetByOrgRepoTagsResponse400ErrorDetails
from .get_by_org_repo_tags_response_401 import GetByOrgRepoTagsResponse401
from .get_by_org_repo_tags_response_401_error import GetByOrgRepoTagsResponse401Error
from .get_by_org_repo_tags_response_401_error_details import GetByOrgRepoTagsResponse401ErrorDetails
from .get_by_org_repo_tags_response_403 import GetByOrgRepoTagsResponse403
from .get_by_org_repo_tags_response_403_error import GetByOrgRepoTagsResponse403Error
from .get_by_org_repo_tags_response_403_error_details import GetByOrgRepoTagsResponse403ErrorDetails
from .get_by_org_repo_tags_response_404 import GetByOrgRepoTagsResponse404
from .get_by_org_repo_tags_response_404_error import GetByOrgRepoTagsResponse404Error
from .get_by_org_repo_tags_response_404_error_details import GetByOrgRepoTagsResponse404ErrorDetails
from .get_by_org_repo_tags_response_406 import GetByOrgRepoTagsResponse406
from .get_by_org_repo_tags_response_406_error import GetByOrgRepoTagsResponse406Error
from .get_by_org_repo_tags_response_406_error_details import GetByOrgRepoTagsResponse406ErrorDetails
from .get_by_org_repo_tags_response_409 import GetByOrgRepoTagsResponse409
from .get_by_org_repo_tags_response_409_error import GetByOrgRepoTagsResponse409Error
from .get_by_org_repo_tags_response_409_error_details import GetByOrgRepoTagsResponse409ErrorDetails
from .get_by_org_repo_tags_response_500 import GetByOrgRepoTagsResponse500
from .get_by_org_repo_tags_response_500_error import GetByOrgRepoTagsResponse500Error
from .get_by_org_repo_tags_response_500_error_details import GetByOrgRepoTagsResponse500ErrorDetails
from .get_by_org_response_200 import GetByOrgResponse200
from .get_by_org_response_400 import GetByOrgResponse400
from .get_by_org_response_400_error import GetByOrgResponse400Error
from .get_by_org_response_400_error_details import GetByOrgResponse400ErrorDetails
from .get_by_org_response_401 import GetByOrgResponse401
from .get_by_org_response_401_error import GetByOrgResponse401Error
from .get_by_org_response_401_error_details import GetByOrgResponse401ErrorDetails
from .get_by_org_response_403 import GetByOrgResponse403
from .get_by_org_response_403_error import GetByOrgResponse403Error
from .get_by_org_response_403_error_details import GetByOrgResponse403ErrorDetails
from .get_by_org_response_404 import GetByOrgResponse404
from .get_by_org_response_404_error import GetByOrgResponse404Error
from .get_by_org_response_404_error_details import GetByOrgResponse404ErrorDetails
from .get_by_org_response_406 import GetByOrgResponse406
from .get_by_org_response_406_error import GetByOrgResponse406Error
from .get_by_org_response_406_error_details import GetByOrgResponse406ErrorDetails
from .get_by_org_response_409 import GetByOrgResponse409
from .get_by_org_response_409_error import GetByOrgResponse409Error
from .get_by_org_response_409_error_details import GetByOrgResponse409ErrorDetails
from .get_by_org_response_500 import GetByOrgResponse500
from .get_by_org_response_500_error import GetByOrgResponse500Error
from .get_by_org_response_500_error_details import GetByOrgResponse500ErrorDetails
from .get_whoami_response_200 import GetWhoamiResponse200
from .get_whoami_response_200_org import GetWhoamiResponse200Org
from .get_whoami_response_400 import GetWhoamiResponse400
from .get_whoami_response_400_error import GetWhoamiResponse400Error
from .get_whoami_response_400_error_details import GetWhoamiResponse400ErrorDetails
from .get_whoami_response_401 import GetWhoamiResponse401
from .get_whoami_response_401_error import GetWhoamiResponse401Error
from .get_whoami_response_401_error_details import GetWhoamiResponse401ErrorDetails
from .get_whoami_response_403 import GetWhoamiResponse403
from .get_whoami_response_403_error import GetWhoamiResponse403Error
from .get_whoami_response_403_error_details import GetWhoamiResponse403ErrorDetails
from .get_whoami_response_404 import GetWhoamiResponse404
from .get_whoami_response_404_error import GetWhoamiResponse404Error
from .get_whoami_response_404_error_details import GetWhoamiResponse404ErrorDetails
from .get_whoami_response_406 import GetWhoamiResponse406
from .get_whoami_response_406_error import GetWhoamiResponse406Error
from .get_whoami_response_406_error_details import GetWhoamiResponse406ErrorDetails
from .get_whoami_response_409 import GetWhoamiResponse409
from .get_whoami_response_409_error import GetWhoamiResponse409Error
from .get_whoami_response_409_error_details import GetWhoamiResponse409ErrorDetails
from .get_whoami_response_500 import GetWhoamiResponse500
from .get_whoami_response_500_error import GetWhoamiResponse500Error
from .get_whoami_response_500_error_details import GetWhoamiResponse500ErrorDetails
from .patch_by_org_by_repo_body import PatchByOrgByRepoBody
from .patch_by_org_by_repo_body_tags import PatchByOrgByRepoBodyTags
from .patch_by_org_by_repo_body_upstream_type_0 import PatchByOrgByRepoBodyUpstreamType0
from .patch_by_org_by_repo_body_upstream_type_0_autosync_type_0 import PatchByOrgByRepoBodyUpstreamType0AutosyncType0
from .patch_by_org_by_repo_body_upstream_type_0_autosync_type_0_resolution_strategy import PatchByOrgByRepoBodyUpstreamType0AutosyncType0ResolutionStrategy
from .patch_by_org_by_repo_response_200 import PatchByOrgByRepoResponse200
from .patch_by_org_by_repo_response_200_tags import PatchByOrgByRepoResponse200Tags
from .patch_by_org_by_repo_response_200_upstream_type_0 import PatchByOrgByRepoResponse200UpstreamType0
from .patch_by_org_by_repo_response_200_upstream_type_0_autosync_type_0 import PatchByOrgByRepoResponse200UpstreamType0AutosyncType0
from .patch_by_org_by_repo_response_200_upstream_type_0_autosync_type_0_resolution_strategy import PatchByOrgByRepoResponse200UpstreamType0AutosyncType0ResolutionStrategy
from .patch_by_org_by_repo_response_400 import PatchByOrgByRepoResponse400
from .patch_by_org_by_repo_response_400_error import PatchByOrgByRepoResponse400Error
from .patch_by_org_by_repo_response_400_error_details import PatchByOrgByRepoResponse400ErrorDetails
from .patch_by_org_by_repo_response_401 import PatchByOrgByRepoResponse401
from .patch_by_org_by_repo_response_401_error import PatchByOrgByRepoResponse401Error
from .patch_by_org_by_repo_response_401_error_details import PatchByOrgByRepoResponse401ErrorDetails
from .patch_by_org_by_repo_response_403 import PatchByOrgByRepoResponse403
from .patch_by_org_by_repo_response_403_error import PatchByOrgByRepoResponse403Error
from .patch_by_org_by_repo_response_403_error_details import PatchByOrgByRepoResponse403ErrorDetails
from .patch_by_org_by_repo_response_404 import PatchByOrgByRepoResponse404
from .patch_by_org_by_repo_response_404_error import PatchByOrgByRepoResponse404Error
from .patch_by_org_by_repo_response_404_error_details import PatchByOrgByRepoResponse404ErrorDetails
from .patch_by_org_by_repo_response_406 import PatchByOrgByRepoResponse406
from .patch_by_org_by_repo_response_406_error import PatchByOrgByRepoResponse406Error
from .patch_by_org_by_repo_response_406_error_details import PatchByOrgByRepoResponse406ErrorDetails
from .patch_by_org_by_repo_response_409 import PatchByOrgByRepoResponse409
from .patch_by_org_by_repo_response_409_error import PatchByOrgByRepoResponse409Error
from .patch_by_org_by_repo_response_409_error_details import PatchByOrgByRepoResponse409ErrorDetails
from .patch_by_org_by_repo_response_500 import PatchByOrgByRepoResponse500
from .patch_by_org_by_repo_response_500_error import PatchByOrgByRepoResponse500Error
from .patch_by_org_by_repo_response_500_error_details import PatchByOrgByRepoResponse500ErrorDetails
from .post_by_org_api_key_body import PostByOrgApiKeyBody
from .post_by_org_api_key_body_scopes_item import PostByOrgApiKeyBodyScopesItem
from .post_by_org_api_key_response_201 import PostByOrgApiKeyResponse201
from .post_by_org_api_key_response_400 import PostByOrgApiKeyResponse400
from .post_by_org_api_key_response_400_error import PostByOrgApiKeyResponse400Error
from .post_by_org_api_key_response_400_error_details import PostByOrgApiKeyResponse400ErrorDetails
from .post_by_org_api_key_response_401 import PostByOrgApiKeyResponse401
from .post_by_org_api_key_response_401_error import PostByOrgApiKeyResponse401Error
from .post_by_org_api_key_response_401_error_details import PostByOrgApiKeyResponse401ErrorDetails
from .post_by_org_api_key_response_403 import PostByOrgApiKeyResponse403
from .post_by_org_api_key_response_403_error import PostByOrgApiKeyResponse403Error
from .post_by_org_api_key_response_403_error_details import PostByOrgApiKeyResponse403ErrorDetails
from .post_by_org_api_key_response_404 import PostByOrgApiKeyResponse404
from .post_by_org_api_key_response_404_error import PostByOrgApiKeyResponse404Error
from .post_by_org_api_key_response_404_error_details import PostByOrgApiKeyResponse404ErrorDetails
from .post_by_org_api_key_response_406 import PostByOrgApiKeyResponse406
from .post_by_org_api_key_response_406_error import PostByOrgApiKeyResponse406Error
from .post_by_org_api_key_response_406_error_details import PostByOrgApiKeyResponse406ErrorDetails
from .post_by_org_api_key_response_409 import PostByOrgApiKeyResponse409
from .post_by_org_api_key_response_409_error import PostByOrgApiKeyResponse409Error
from .post_by_org_api_key_response_409_error_details import PostByOrgApiKeyResponse409ErrorDetails
from .post_by_org_api_key_response_500 import PostByOrgApiKeyResponse500
from .post_by_org_api_key_response_500_error import PostByOrgApiKeyResponse500Error
from .post_by_org_api_key_response_500_error_details import PostByOrgApiKeyResponse500ErrorDetails
from .post_by_org_by_repo_branch_body import PostByOrgByRepoBranchBody
from .post_by_org_by_repo_branch_response_201 import PostByOrgByRepoBranchResponse201
from .post_by_org_by_repo_branch_response_400 import PostByOrgByRepoBranchResponse400
from .post_by_org_by_repo_branch_response_400_error import PostByOrgByRepoBranchResponse400Error
from .post_by_org_by_repo_branch_response_400_error_details import PostByOrgByRepoBranchResponse400ErrorDetails
from .post_by_org_by_repo_branch_response_401 import PostByOrgByRepoBranchResponse401
from .post_by_org_by_repo_branch_response_401_error import PostByOrgByRepoBranchResponse401Error
from .post_by_org_by_repo_branch_response_401_error_details import PostByOrgByRepoBranchResponse401ErrorDetails
from .post_by_org_by_repo_branch_response_403 import PostByOrgByRepoBranchResponse403
from .post_by_org_by_repo_branch_response_403_error import PostByOrgByRepoBranchResponse403Error
from .post_by_org_by_repo_branch_response_403_error_details import PostByOrgByRepoBranchResponse403ErrorDetails
from .post_by_org_by_repo_branch_response_404 import PostByOrgByRepoBranchResponse404
from .post_by_org_by_repo_branch_response_404_error import PostByOrgByRepoBranchResponse404Error
from .post_by_org_by_repo_branch_response_404_error_details import PostByOrgByRepoBranchResponse404ErrorDetails
from .post_by_org_by_repo_branch_response_406 import PostByOrgByRepoBranchResponse406
from .post_by_org_by_repo_branch_response_406_error import PostByOrgByRepoBranchResponse406Error
from .post_by_org_by_repo_branch_response_406_error_details import PostByOrgByRepoBranchResponse406ErrorDetails
from .post_by_org_by_repo_branch_response_409 import PostByOrgByRepoBranchResponse409
from .post_by_org_by_repo_branch_response_409_error import PostByOrgByRepoBranchResponse409Error
from .post_by_org_by_repo_branch_response_409_error_details import PostByOrgByRepoBranchResponse409ErrorDetails
from .post_by_org_by_repo_branch_response_500 import PostByOrgByRepoBranchResponse500
from .post_by_org_by_repo_branch_response_500_error import PostByOrgByRepoBranchResponse500Error
from .post_by_org_by_repo_branch_response_500_error_details import PostByOrgByRepoBranchResponse500ErrorDetails
from .post_by_org_by_repo_commit_body import PostByOrgByRepoCommitBody
from .post_by_org_by_repo_commit_body_author import PostByOrgByRepoCommitBodyAuthor
from .post_by_org_by_repo_commit_body_committer import PostByOrgByRepoCommitBodyCommitter
from .post_by_org_by_repo_commit_body_files_item_type_0 import PostByOrgByRepoCommitBodyFilesItemType0
from .post_by_org_by_repo_commit_body_files_item_type_0_encoding import PostByOrgByRepoCommitBodyFilesItemType0Encoding
from .post_by_org_by_repo_commit_body_files_item_type_0_mode import PostByOrgByRepoCommitBodyFilesItemType0Mode
from .post_by_org_by_repo_commit_body_files_item_type_1 import PostByOrgByRepoCommitBodyFilesItemType1
from .post_by_org_by_repo_commit_response_201 import PostByOrgByRepoCommitResponse201
from .post_by_org_by_repo_commit_response_400 import PostByOrgByRepoCommitResponse400
from .post_by_org_by_repo_commit_response_400_error import PostByOrgByRepoCommitResponse400Error
from .post_by_org_by_repo_commit_response_400_error_details import PostByOrgByRepoCommitResponse400ErrorDetails
from .post_by_org_by_repo_commit_response_401 import PostByOrgByRepoCommitResponse401
from .post_by_org_by_repo_commit_response_401_error import PostByOrgByRepoCommitResponse401Error
from .post_by_org_by_repo_commit_response_401_error_details import PostByOrgByRepoCommitResponse401ErrorDetails
from .post_by_org_by_repo_commit_response_403 import PostByOrgByRepoCommitResponse403
from .post_by_org_by_repo_commit_response_403_error import PostByOrgByRepoCommitResponse403Error
from .post_by_org_by_repo_commit_response_403_error_details import PostByOrgByRepoCommitResponse403ErrorDetails
from .post_by_org_by_repo_commit_response_404 import PostByOrgByRepoCommitResponse404
from .post_by_org_by_repo_commit_response_404_error import PostByOrgByRepoCommitResponse404Error
from .post_by_org_by_repo_commit_response_404_error_details import PostByOrgByRepoCommitResponse404ErrorDetails
from .post_by_org_by_repo_commit_response_406 import PostByOrgByRepoCommitResponse406
from .post_by_org_by_repo_commit_response_406_error import PostByOrgByRepoCommitResponse406Error
from .post_by_org_by_repo_commit_response_406_error_details import PostByOrgByRepoCommitResponse406ErrorDetails
from .post_by_org_by_repo_commit_response_409 import PostByOrgByRepoCommitResponse409
from .post_by_org_by_repo_commit_response_409_error import PostByOrgByRepoCommitResponse409Error
from .post_by_org_by_repo_commit_response_409_error_details import PostByOrgByRepoCommitResponse409ErrorDetails
from .post_by_org_by_repo_commit_response_500 import PostByOrgByRepoCommitResponse500
from .post_by_org_by_repo_commit_response_500_error import PostByOrgByRepoCommitResponse500Error
from .post_by_org_by_repo_commit_response_500_error_details import PostByOrgByRepoCommitResponse500ErrorDetails
from .post_by_org_by_repo_webhook_body import PostByOrgByRepoWebhookBody
from .post_by_org_by_repo_webhook_body_events_item import PostByOrgByRepoWebhookBodyEventsItem
from .post_by_org_by_repo_webhook_response_201 import PostByOrgByRepoWebhookResponse201
from .post_by_org_by_repo_webhook_response_201_events_item import PostByOrgByRepoWebhookResponse201EventsItem
from .post_by_org_by_repo_webhook_response_400 import PostByOrgByRepoWebhookResponse400
from .post_by_org_by_repo_webhook_response_400_error import PostByOrgByRepoWebhookResponse400Error
from .post_by_org_by_repo_webhook_response_400_error_details import PostByOrgByRepoWebhookResponse400ErrorDetails
from .post_by_org_by_repo_webhook_response_401 import PostByOrgByRepoWebhookResponse401
from .post_by_org_by_repo_webhook_response_401_error import PostByOrgByRepoWebhookResponse401Error
from .post_by_org_by_repo_webhook_response_401_error_details import PostByOrgByRepoWebhookResponse401ErrorDetails
from .post_by_org_by_repo_webhook_response_403 import PostByOrgByRepoWebhookResponse403
from .post_by_org_by_repo_webhook_response_403_error import PostByOrgByRepoWebhookResponse403Error
from .post_by_org_by_repo_webhook_response_403_error_details import PostByOrgByRepoWebhookResponse403ErrorDetails
from .post_by_org_by_repo_webhook_response_404 import PostByOrgByRepoWebhookResponse404
from .post_by_org_by_repo_webhook_response_404_error import PostByOrgByRepoWebhookResponse404Error
from .post_by_org_by_repo_webhook_response_404_error_details import PostByOrgByRepoWebhookResponse404ErrorDetails
from .post_by_org_by_repo_webhook_response_406 import PostByOrgByRepoWebhookResponse406
from .post_by_org_by_repo_webhook_response_406_error import PostByOrgByRepoWebhookResponse406Error
from .post_by_org_by_repo_webhook_response_406_error_details import PostByOrgByRepoWebhookResponse406ErrorDetails
from .post_by_org_by_repo_webhook_response_409 import PostByOrgByRepoWebhookResponse409
from .post_by_org_by_repo_webhook_response_409_error import PostByOrgByRepoWebhookResponse409Error
from .post_by_org_by_repo_webhook_response_409_error_details import PostByOrgByRepoWebhookResponse409ErrorDetails
from .post_by_org_by_repo_webhook_response_500 import PostByOrgByRepoWebhookResponse500
from .post_by_org_by_repo_webhook_response_500_error import PostByOrgByRepoWebhookResponse500Error
from .post_by_org_by_repo_webhook_response_500_error_details import PostByOrgByRepoWebhookResponse500ErrorDetails
from .post_by_org_repo_body import PostByOrgRepoBody
from .post_by_org_repo_body_tags import PostByOrgRepoBodyTags
from .post_by_org_repo_body_upstream import PostByOrgRepoBodyUpstream
from .post_by_org_repo_body_upstream_autosync_type_0 import PostByOrgRepoBodyUpstreamAutosyncType0
from .post_by_org_repo_body_upstream_autosync_type_0_resolution_strategy import PostByOrgRepoBodyUpstreamAutosyncType0ResolutionStrategy
from .post_by_org_repo_bulk_tags_body import PostByOrgRepoBulkTagsBody
from .post_by_org_repo_bulk_tags_body_action import PostByOrgRepoBulkTagsBodyAction
from .post_by_org_repo_bulk_tags_response_200 import PostByOrgRepoBulkTagsResponse200
from .post_by_org_repo_bulk_tags_response_400 import PostByOrgRepoBulkTagsResponse400
from .post_by_org_repo_bulk_tags_response_400_error import PostByOrgRepoBulkTagsResponse400Error
from .post_by_org_repo_bulk_tags_response_400_error_details import PostByOrgRepoBulkTagsResponse400ErrorDetails
from .post_by_org_repo_bulk_tags_response_401 import PostByOrgRepoBulkTagsResponse401
from .post_by_org_repo_bulk_tags_response_401_error import PostByOrgRepoBulkTagsResponse401Error
from .post_by_org_repo_bulk_tags_response_401_error_details import PostByOrgRepoBulkTagsResponse401ErrorDetails
from .post_by_org_repo_bulk_tags_response_403 import PostByOrgRepoBulkTagsResponse403
from .post_by_org_repo_bulk_tags_response_403_error import PostByOrgRepoBulkTagsResponse403Error
from .post_by_org_repo_bulk_tags_response_403_error_details import PostByOrgRepoBulkTagsResponse403ErrorDetails
from .post_by_org_repo_bulk_tags_response_404 import PostByOrgRepoBulkTagsResponse404
from .post_by_org_repo_bulk_tags_response_404_error import PostByOrgRepoBulkTagsResponse404Error
from .post_by_org_repo_bulk_tags_response_404_error_details import PostByOrgRepoBulkTagsResponse404ErrorDetails
from .post_by_org_repo_bulk_tags_response_406 import PostByOrgRepoBulkTagsResponse406
from .post_by_org_repo_bulk_tags_response_406_error import PostByOrgRepoBulkTagsResponse406Error
from .post_by_org_repo_bulk_tags_response_406_error_details import PostByOrgRepoBulkTagsResponse406ErrorDetails
from .post_by_org_repo_bulk_tags_response_409 import PostByOrgRepoBulkTagsResponse409
from .post_by_org_repo_bulk_tags_response_409_error import PostByOrgRepoBulkTagsResponse409Error
from .post_by_org_repo_bulk_tags_response_409_error_details import PostByOrgRepoBulkTagsResponse409ErrorDetails
from .post_by_org_repo_bulk_tags_response_500 import PostByOrgRepoBulkTagsResponse500
from .post_by_org_repo_bulk_tags_response_500_error import PostByOrgRepoBulkTagsResponse500Error
from .post_by_org_repo_bulk_tags_response_500_error_details import PostByOrgRepoBulkTagsResponse500ErrorDetails
from .post_by_org_repo_response_201 import PostByOrgRepoResponse201
from .post_by_org_repo_response_201_tags import PostByOrgRepoResponse201Tags
from .post_by_org_repo_response_201_upstream_type_0 import PostByOrgRepoResponse201UpstreamType0
from .post_by_org_repo_response_201_upstream_type_0_autosync_type_0 import PostByOrgRepoResponse201UpstreamType0AutosyncType0
from .post_by_org_repo_response_201_upstream_type_0_autosync_type_0_resolution_strategy import PostByOrgRepoResponse201UpstreamType0AutosyncType0ResolutionStrategy
from .post_by_org_repo_response_400 import PostByOrgRepoResponse400
from .post_by_org_repo_response_400_error import PostByOrgRepoResponse400Error
from .post_by_org_repo_response_400_error_details import PostByOrgRepoResponse400ErrorDetails
from .post_by_org_repo_response_401 import PostByOrgRepoResponse401
from .post_by_org_repo_response_401_error import PostByOrgRepoResponse401Error
from .post_by_org_repo_response_401_error_details import PostByOrgRepoResponse401ErrorDetails
from .post_by_org_repo_response_403 import PostByOrgRepoResponse403
from .post_by_org_repo_response_403_error import PostByOrgRepoResponse403Error
from .post_by_org_repo_response_403_error_details import PostByOrgRepoResponse403ErrorDetails
from .post_by_org_repo_response_404 import PostByOrgRepoResponse404
from .post_by_org_repo_response_404_error import PostByOrgRepoResponse404Error
from .post_by_org_repo_response_404_error_details import PostByOrgRepoResponse404ErrorDetails
from .post_by_org_repo_response_406 import PostByOrgRepoResponse406
from .post_by_org_repo_response_406_error import PostByOrgRepoResponse406Error
from .post_by_org_repo_response_406_error_details import PostByOrgRepoResponse406ErrorDetails
from .post_by_org_repo_response_409 import PostByOrgRepoResponse409
from .post_by_org_repo_response_409_error import PostByOrgRepoResponse409Error
from .post_by_org_repo_response_409_error_details import PostByOrgRepoResponse409ErrorDetails
from .post_by_org_repo_response_500 import PostByOrgRepoResponse500
from .post_by_org_repo_response_500_error import PostByOrgRepoResponse500Error
from .post_by_org_repo_response_500_error_details import PostByOrgRepoResponse500ErrorDetails

__all__ = (
    "DeleteByOrgApiKeyByIdResponse200",
    "DeleteByOrgApiKeyByIdResponse400",
    "DeleteByOrgApiKeyByIdResponse400Error",
    "DeleteByOrgApiKeyByIdResponse400ErrorDetails",
    "DeleteByOrgApiKeyByIdResponse401",
    "DeleteByOrgApiKeyByIdResponse401Error",
    "DeleteByOrgApiKeyByIdResponse401ErrorDetails",
    "DeleteByOrgApiKeyByIdResponse403",
    "DeleteByOrgApiKeyByIdResponse403Error",
    "DeleteByOrgApiKeyByIdResponse403ErrorDetails",
    "DeleteByOrgApiKeyByIdResponse404",
    "DeleteByOrgApiKeyByIdResponse404Error",
    "DeleteByOrgApiKeyByIdResponse404ErrorDetails",
    "DeleteByOrgApiKeyByIdResponse406",
    "DeleteByOrgApiKeyByIdResponse406Error",
    "DeleteByOrgApiKeyByIdResponse406ErrorDetails",
    "DeleteByOrgApiKeyByIdResponse409",
    "DeleteByOrgApiKeyByIdResponse409Error",
    "DeleteByOrgApiKeyByIdResponse409ErrorDetails",
    "DeleteByOrgApiKeyByIdResponse500",
    "DeleteByOrgApiKeyByIdResponse500Error",
    "DeleteByOrgApiKeyByIdResponse500ErrorDetails",
    "DeleteByOrgByRepoBranchByBranchResponse200",
    "DeleteByOrgByRepoBranchByBranchResponse400",
    "DeleteByOrgByRepoBranchByBranchResponse400Error",
    "DeleteByOrgByRepoBranchByBranchResponse400ErrorDetails",
    "DeleteByOrgByRepoBranchByBranchResponse401",
    "DeleteByOrgByRepoBranchByBranchResponse401Error",
    "DeleteByOrgByRepoBranchByBranchResponse401ErrorDetails",
    "DeleteByOrgByRepoBranchByBranchResponse403",
    "DeleteByOrgByRepoBranchByBranchResponse403Error",
    "DeleteByOrgByRepoBranchByBranchResponse403ErrorDetails",
    "DeleteByOrgByRepoBranchByBranchResponse404",
    "DeleteByOrgByRepoBranchByBranchResponse404Error",
    "DeleteByOrgByRepoBranchByBranchResponse404ErrorDetails",
    "DeleteByOrgByRepoBranchByBranchResponse406",
    "DeleteByOrgByRepoBranchByBranchResponse406Error",
    "DeleteByOrgByRepoBranchByBranchResponse406ErrorDetails",
    "DeleteByOrgByRepoBranchByBranchResponse409",
    "DeleteByOrgByRepoBranchByBranchResponse409Error",
    "DeleteByOrgByRepoBranchByBranchResponse409ErrorDetails",
    "DeleteByOrgByRepoBranchByBranchResponse500",
    "DeleteByOrgByRepoBranchByBranchResponse500Error",
    "DeleteByOrgByRepoBranchByBranchResponse500ErrorDetails",
    "DeleteByOrgByRepoResponse200",
    "DeleteByOrgByRepoResponse400",
    "DeleteByOrgByRepoResponse400Error",
    "DeleteByOrgByRepoResponse400ErrorDetails",
    "DeleteByOrgByRepoResponse401",
    "DeleteByOrgByRepoResponse401Error",
    "DeleteByOrgByRepoResponse401ErrorDetails",
    "DeleteByOrgByRepoResponse403",
    "DeleteByOrgByRepoResponse403Error",
    "DeleteByOrgByRepoResponse403ErrorDetails",
    "DeleteByOrgByRepoResponse404",
    "DeleteByOrgByRepoResponse404Error",
    "DeleteByOrgByRepoResponse404ErrorDetails",
    "DeleteByOrgByRepoResponse406",
    "DeleteByOrgByRepoResponse406Error",
    "DeleteByOrgByRepoResponse406ErrorDetails",
    "DeleteByOrgByRepoResponse409",
    "DeleteByOrgByRepoResponse409Error",
    "DeleteByOrgByRepoResponse409ErrorDetails",
    "DeleteByOrgByRepoResponse500",
    "DeleteByOrgByRepoResponse500Error",
    "DeleteByOrgByRepoResponse500ErrorDetails",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse200",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse400",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse400Error",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse400ErrorDetails",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse401",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse401Error",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse401ErrorDetails",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse403",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse403Error",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse403ErrorDetails",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse404",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse404Error",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse404ErrorDetails",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse406",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse406Error",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse406ErrorDetails",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse409",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse409Error",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse409ErrorDetails",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse500",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse500Error",
    "DeleteByOrgByRepoWebhookByWebhookIdResponse500ErrorDetails",
    "GetByOrgApiKeyResponse200",
    "GetByOrgApiKeyResponse200ApiKeysItem",
    "GetByOrgApiKeyResponse400",
    "GetByOrgApiKeyResponse400Error",
    "GetByOrgApiKeyResponse400ErrorDetails",
    "GetByOrgApiKeyResponse401",
    "GetByOrgApiKeyResponse401Error",
    "GetByOrgApiKeyResponse401ErrorDetails",
    "GetByOrgApiKeyResponse403",
    "GetByOrgApiKeyResponse403Error",
    "GetByOrgApiKeyResponse403ErrorDetails",
    "GetByOrgApiKeyResponse404",
    "GetByOrgApiKeyResponse404Error",
    "GetByOrgApiKeyResponse404ErrorDetails",
    "GetByOrgApiKeyResponse406",
    "GetByOrgApiKeyResponse406Error",
    "GetByOrgApiKeyResponse406ErrorDetails",
    "GetByOrgApiKeyResponse409",
    "GetByOrgApiKeyResponse409Error",
    "GetByOrgApiKeyResponse409ErrorDetails",
    "GetByOrgApiKeyResponse500",
    "GetByOrgApiKeyResponse500Error",
    "GetByOrgApiKeyResponse500ErrorDetails",
    "GetByOrgByRepoBranchResponse200",
    "GetByOrgByRepoBranchResponse200BranchesItem",
    "GetByOrgByRepoBranchResponse400",
    "GetByOrgByRepoBranchResponse400Error",
    "GetByOrgByRepoBranchResponse400ErrorDetails",
    "GetByOrgByRepoBranchResponse401",
    "GetByOrgByRepoBranchResponse401Error",
    "GetByOrgByRepoBranchResponse401ErrorDetails",
    "GetByOrgByRepoBranchResponse403",
    "GetByOrgByRepoBranchResponse403Error",
    "GetByOrgByRepoBranchResponse403ErrorDetails",
    "GetByOrgByRepoBranchResponse404",
    "GetByOrgByRepoBranchResponse404Error",
    "GetByOrgByRepoBranchResponse404ErrorDetails",
    "GetByOrgByRepoBranchResponse406",
    "GetByOrgByRepoBranchResponse406Error",
    "GetByOrgByRepoBranchResponse406ErrorDetails",
    "GetByOrgByRepoBranchResponse409",
    "GetByOrgByRepoBranchResponse409Error",
    "GetByOrgByRepoBranchResponse409ErrorDetails",
    "GetByOrgByRepoBranchResponse500",
    "GetByOrgByRepoBranchResponse500Error",
    "GetByOrgByRepoBranchResponse500ErrorDetails",
    "GetByOrgByRepoCommitByShaResponse200",
    "GetByOrgByRepoCommitByShaResponse200Author",
    "GetByOrgByRepoCommitByShaResponse200Committer",
    "GetByOrgByRepoCommitByShaResponse400",
    "GetByOrgByRepoCommitByShaResponse400Error",
    "GetByOrgByRepoCommitByShaResponse400ErrorDetails",
    "GetByOrgByRepoCommitByShaResponse401",
    "GetByOrgByRepoCommitByShaResponse401Error",
    "GetByOrgByRepoCommitByShaResponse401ErrorDetails",
    "GetByOrgByRepoCommitByShaResponse403",
    "GetByOrgByRepoCommitByShaResponse403Error",
    "GetByOrgByRepoCommitByShaResponse403ErrorDetails",
    "GetByOrgByRepoCommitByShaResponse404",
    "GetByOrgByRepoCommitByShaResponse404Error",
    "GetByOrgByRepoCommitByShaResponse404ErrorDetails",
    "GetByOrgByRepoCommitByShaResponse406",
    "GetByOrgByRepoCommitByShaResponse406Error",
    "GetByOrgByRepoCommitByShaResponse406ErrorDetails",
    "GetByOrgByRepoCommitByShaResponse409",
    "GetByOrgByRepoCommitByShaResponse409Error",
    "GetByOrgByRepoCommitByShaResponse409ErrorDetails",
    "GetByOrgByRepoCommitByShaResponse500",
    "GetByOrgByRepoCommitByShaResponse500Error",
    "GetByOrgByRepoCommitByShaResponse500ErrorDetails",
    "GetByOrgByRepoCommitResponse200",
    "GetByOrgByRepoCommitResponse200CommitsItem",
    "GetByOrgByRepoCommitResponse200CommitsItemAuthor",
    "GetByOrgByRepoCommitResponse200CommitsItemCommitter",
    "GetByOrgByRepoCommitResponse400",
    "GetByOrgByRepoCommitResponse400Error",
    "GetByOrgByRepoCommitResponse400ErrorDetails",
    "GetByOrgByRepoCommitResponse401",
    "GetByOrgByRepoCommitResponse401Error",
    "GetByOrgByRepoCommitResponse401ErrorDetails",
    "GetByOrgByRepoCommitResponse403",
    "GetByOrgByRepoCommitResponse403Error",
    "GetByOrgByRepoCommitResponse403ErrorDetails",
    "GetByOrgByRepoCommitResponse404",
    "GetByOrgByRepoCommitResponse404Error",
    "GetByOrgByRepoCommitResponse404ErrorDetails",
    "GetByOrgByRepoCommitResponse406",
    "GetByOrgByRepoCommitResponse406Error",
    "GetByOrgByRepoCommitResponse406ErrorDetails",
    "GetByOrgByRepoCommitResponse409",
    "GetByOrgByRepoCommitResponse409Error",
    "GetByOrgByRepoCommitResponse409ErrorDetails",
    "GetByOrgByRepoCommitResponse500",
    "GetByOrgByRepoCommitResponse500Error",
    "GetByOrgByRepoCommitResponse500ErrorDetails",
    "GetByOrgByRepoContentResponse200Type0",
    "GetByOrgByRepoContentResponse200Type1",
    "GetByOrgByRepoContentResponse200Type2",
    "GetByOrgByRepoContentResponse200Type2EntriesItemType0",
    "GetByOrgByRepoContentResponse200Type2EntriesItemType1",
    "GetByOrgByRepoContentResponse200Type2EntriesItemType2",
    "GetByOrgByRepoContentResponse400",
    "GetByOrgByRepoContentResponse400Error",
    "GetByOrgByRepoContentResponse400ErrorDetails",
    "GetByOrgByRepoContentResponse401",
    "GetByOrgByRepoContentResponse401Error",
    "GetByOrgByRepoContentResponse401ErrorDetails",
    "GetByOrgByRepoContentResponse403",
    "GetByOrgByRepoContentResponse403Error",
    "GetByOrgByRepoContentResponse403ErrorDetails",
    "GetByOrgByRepoContentResponse404",
    "GetByOrgByRepoContentResponse404Error",
    "GetByOrgByRepoContentResponse404ErrorDetails",
    "GetByOrgByRepoContentResponse406",
    "GetByOrgByRepoContentResponse406Error",
    "GetByOrgByRepoContentResponse406ErrorDetails",
    "GetByOrgByRepoContentResponse409",
    "GetByOrgByRepoContentResponse409Error",
    "GetByOrgByRepoContentResponse409ErrorDetails",
    "GetByOrgByRepoContentResponse500",
    "GetByOrgByRepoContentResponse500Error",
    "GetByOrgByRepoContentResponse500ErrorDetails",
    "GetByOrgByRepoDiffResponse200",
    "GetByOrgByRepoDiffResponse200FilesItem",
    "GetByOrgByRepoDiffResponse200FilesItemStatus",
    "GetByOrgByRepoDiffResponse200FilteredFilesItem",
    "GetByOrgByRepoDiffResponse200FilteredFilesItemStatus",
    "GetByOrgByRepoDiffResponse200Stats",
    "GetByOrgByRepoDiffResponse400",
    "GetByOrgByRepoDiffResponse400Error",
    "GetByOrgByRepoDiffResponse400ErrorDetails",
    "GetByOrgByRepoDiffResponse401",
    "GetByOrgByRepoDiffResponse401Error",
    "GetByOrgByRepoDiffResponse401ErrorDetails",
    "GetByOrgByRepoDiffResponse403",
    "GetByOrgByRepoDiffResponse403Error",
    "GetByOrgByRepoDiffResponse403ErrorDetails",
    "GetByOrgByRepoDiffResponse404",
    "GetByOrgByRepoDiffResponse404Error",
    "GetByOrgByRepoDiffResponse404ErrorDetails",
    "GetByOrgByRepoDiffResponse406",
    "GetByOrgByRepoDiffResponse406Error",
    "GetByOrgByRepoDiffResponse406ErrorDetails",
    "GetByOrgByRepoDiffResponse409",
    "GetByOrgByRepoDiffResponse409Error",
    "GetByOrgByRepoDiffResponse409ErrorDetails",
    "GetByOrgByRepoDiffResponse500",
    "GetByOrgByRepoDiffResponse500Error",
    "GetByOrgByRepoDiffResponse500ErrorDetails",
    "GetByOrgByRepoResponse200",
    "GetByOrgByRepoResponse200Tags",
    "GetByOrgByRepoResponse200UpstreamType0",
    "GetByOrgByRepoResponse200UpstreamType0AutosyncType0",
    "GetByOrgByRepoResponse200UpstreamType0AutosyncType0ResolutionStrategy",
    "GetByOrgByRepoResponse400",
    "GetByOrgByRepoResponse400Error",
    "GetByOrgByRepoResponse400ErrorDetails",
    "GetByOrgByRepoResponse401",
    "GetByOrgByRepoResponse401Error",
    "GetByOrgByRepoResponse401ErrorDetails",
    "GetByOrgByRepoResponse403",
    "GetByOrgByRepoResponse403Error",
    "GetByOrgByRepoResponse403ErrorDetails",
    "GetByOrgByRepoResponse404",
    "GetByOrgByRepoResponse404Error",
    "GetByOrgByRepoResponse404ErrorDetails",
    "GetByOrgByRepoResponse406",
    "GetByOrgByRepoResponse406Error",
    "GetByOrgByRepoResponse406ErrorDetails",
    "GetByOrgByRepoResponse409",
    "GetByOrgByRepoResponse409Error",
    "GetByOrgByRepoResponse409ErrorDetails",
    "GetByOrgByRepoResponse500",
    "GetByOrgByRepoResponse500Error",
    "GetByOrgByRepoResponse500ErrorDetails",
    "GetByOrgByRepoWebhookResponse200",
    "GetByOrgByRepoWebhookResponse200WebhooksItem",
    "GetByOrgByRepoWebhookResponse200WebhooksItemEventsItem",
    "GetByOrgByRepoWebhookResponse400",
    "GetByOrgByRepoWebhookResponse400Error",
    "GetByOrgByRepoWebhookResponse400ErrorDetails",
    "GetByOrgByRepoWebhookResponse401",
    "GetByOrgByRepoWebhookResponse401Error",
    "GetByOrgByRepoWebhookResponse401ErrorDetails",
    "GetByOrgByRepoWebhookResponse403",
    "GetByOrgByRepoWebhookResponse403Error",
    "GetByOrgByRepoWebhookResponse403ErrorDetails",
    "GetByOrgByRepoWebhookResponse404",
    "GetByOrgByRepoWebhookResponse404Error",
    "GetByOrgByRepoWebhookResponse404ErrorDetails",
    "GetByOrgByRepoWebhookResponse406",
    "GetByOrgByRepoWebhookResponse406Error",
    "GetByOrgByRepoWebhookResponse406ErrorDetails",
    "GetByOrgByRepoWebhookResponse409",
    "GetByOrgByRepoWebhookResponse409Error",
    "GetByOrgByRepoWebhookResponse409ErrorDetails",
    "GetByOrgByRepoWebhookResponse500",
    "GetByOrgByRepoWebhookResponse500Error",
    "GetByOrgByRepoWebhookResponse500ErrorDetails",
    "GetByOrgRepoResponse200",
    "GetByOrgRepoResponse200ReposItem",
    "GetByOrgRepoResponse200ReposItemTags",
    "GetByOrgRepoResponse200ReposItemUpstreamType0",
    "GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0",
    "GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0ResolutionStrategy",
    "GetByOrgRepoResponse400",
    "GetByOrgRepoResponse400Error",
    "GetByOrgRepoResponse400ErrorDetails",
    "GetByOrgRepoResponse401",
    "GetByOrgRepoResponse401Error",
    "GetByOrgRepoResponse401ErrorDetails",
    "GetByOrgRepoResponse403",
    "GetByOrgRepoResponse403Error",
    "GetByOrgRepoResponse403ErrorDetails",
    "GetByOrgRepoResponse404",
    "GetByOrgRepoResponse404Error",
    "GetByOrgRepoResponse404ErrorDetails",
    "GetByOrgRepoResponse406",
    "GetByOrgRepoResponse406Error",
    "GetByOrgRepoResponse406ErrorDetails",
    "GetByOrgRepoResponse409",
    "GetByOrgRepoResponse409Error",
    "GetByOrgRepoResponse409ErrorDetails",
    "GetByOrgRepoResponse500",
    "GetByOrgRepoResponse500Error",
    "GetByOrgRepoResponse500ErrorDetails",
    "GetByOrgRepoTagsResponse200",
    "GetByOrgRepoTagsResponse200Tags",
    "GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem",
    "GetByOrgRepoTagsResponse400",
    "GetByOrgRepoTagsResponse400Error",
    "GetByOrgRepoTagsResponse400ErrorDetails",
    "GetByOrgRepoTagsResponse401",
    "GetByOrgRepoTagsResponse401Error",
    "GetByOrgRepoTagsResponse401ErrorDetails",
    "GetByOrgRepoTagsResponse403",
    "GetByOrgRepoTagsResponse403Error",
    "GetByOrgRepoTagsResponse403ErrorDetails",
    "GetByOrgRepoTagsResponse404",
    "GetByOrgRepoTagsResponse404Error",
    "GetByOrgRepoTagsResponse404ErrorDetails",
    "GetByOrgRepoTagsResponse406",
    "GetByOrgRepoTagsResponse406Error",
    "GetByOrgRepoTagsResponse406ErrorDetails",
    "GetByOrgRepoTagsResponse409",
    "GetByOrgRepoTagsResponse409Error",
    "GetByOrgRepoTagsResponse409ErrorDetails",
    "GetByOrgRepoTagsResponse500",
    "GetByOrgRepoTagsResponse500Error",
    "GetByOrgRepoTagsResponse500ErrorDetails",
    "GetByOrgResponse200",
    "GetByOrgResponse400",
    "GetByOrgResponse400Error",
    "GetByOrgResponse400ErrorDetails",
    "GetByOrgResponse401",
    "GetByOrgResponse401Error",
    "GetByOrgResponse401ErrorDetails",
    "GetByOrgResponse403",
    "GetByOrgResponse403Error",
    "GetByOrgResponse403ErrorDetails",
    "GetByOrgResponse404",
    "GetByOrgResponse404Error",
    "GetByOrgResponse404ErrorDetails",
    "GetByOrgResponse406",
    "GetByOrgResponse406Error",
    "GetByOrgResponse406ErrorDetails",
    "GetByOrgResponse409",
    "GetByOrgResponse409Error",
    "GetByOrgResponse409ErrorDetails",
    "GetByOrgResponse500",
    "GetByOrgResponse500Error",
    "GetByOrgResponse500ErrorDetails",
    "GetWhoamiResponse200",
    "GetWhoamiResponse200Org",
    "GetWhoamiResponse400",
    "GetWhoamiResponse400Error",
    "GetWhoamiResponse400ErrorDetails",
    "GetWhoamiResponse401",
    "GetWhoamiResponse401Error",
    "GetWhoamiResponse401ErrorDetails",
    "GetWhoamiResponse403",
    "GetWhoamiResponse403Error",
    "GetWhoamiResponse403ErrorDetails",
    "GetWhoamiResponse404",
    "GetWhoamiResponse404Error",
    "GetWhoamiResponse404ErrorDetails",
    "GetWhoamiResponse406",
    "GetWhoamiResponse406Error",
    "GetWhoamiResponse406ErrorDetails",
    "GetWhoamiResponse409",
    "GetWhoamiResponse409Error",
    "GetWhoamiResponse409ErrorDetails",
    "GetWhoamiResponse500",
    "GetWhoamiResponse500Error",
    "GetWhoamiResponse500ErrorDetails",
    "PatchByOrgByRepoBody",
    "PatchByOrgByRepoBodyTags",
    "PatchByOrgByRepoBodyUpstreamType0",
    "PatchByOrgByRepoBodyUpstreamType0AutosyncType0",
    "PatchByOrgByRepoBodyUpstreamType0AutosyncType0ResolutionStrategy",
    "PatchByOrgByRepoResponse200",
    "PatchByOrgByRepoResponse200Tags",
    "PatchByOrgByRepoResponse200UpstreamType0",
    "PatchByOrgByRepoResponse200UpstreamType0AutosyncType0",
    "PatchByOrgByRepoResponse200UpstreamType0AutosyncType0ResolutionStrategy",
    "PatchByOrgByRepoResponse400",
    "PatchByOrgByRepoResponse400Error",
    "PatchByOrgByRepoResponse400ErrorDetails",
    "PatchByOrgByRepoResponse401",
    "PatchByOrgByRepoResponse401Error",
    "PatchByOrgByRepoResponse401ErrorDetails",
    "PatchByOrgByRepoResponse403",
    "PatchByOrgByRepoResponse403Error",
    "PatchByOrgByRepoResponse403ErrorDetails",
    "PatchByOrgByRepoResponse404",
    "PatchByOrgByRepoResponse404Error",
    "PatchByOrgByRepoResponse404ErrorDetails",
    "PatchByOrgByRepoResponse406",
    "PatchByOrgByRepoResponse406Error",
    "PatchByOrgByRepoResponse406ErrorDetails",
    "PatchByOrgByRepoResponse409",
    "PatchByOrgByRepoResponse409Error",
    "PatchByOrgByRepoResponse409ErrorDetails",
    "PatchByOrgByRepoResponse500",
    "PatchByOrgByRepoResponse500Error",
    "PatchByOrgByRepoResponse500ErrorDetails",
    "PostByOrgApiKeyBody",
    "PostByOrgApiKeyBodyScopesItem",
    "PostByOrgApiKeyResponse201",
    "PostByOrgApiKeyResponse400",
    "PostByOrgApiKeyResponse400Error",
    "PostByOrgApiKeyResponse400ErrorDetails",
    "PostByOrgApiKeyResponse401",
    "PostByOrgApiKeyResponse401Error",
    "PostByOrgApiKeyResponse401ErrorDetails",
    "PostByOrgApiKeyResponse403",
    "PostByOrgApiKeyResponse403Error",
    "PostByOrgApiKeyResponse403ErrorDetails",
    "PostByOrgApiKeyResponse404",
    "PostByOrgApiKeyResponse404Error",
    "PostByOrgApiKeyResponse404ErrorDetails",
    "PostByOrgApiKeyResponse406",
    "PostByOrgApiKeyResponse406Error",
    "PostByOrgApiKeyResponse406ErrorDetails",
    "PostByOrgApiKeyResponse409",
    "PostByOrgApiKeyResponse409Error",
    "PostByOrgApiKeyResponse409ErrorDetails",
    "PostByOrgApiKeyResponse500",
    "PostByOrgApiKeyResponse500Error",
    "PostByOrgApiKeyResponse500ErrorDetails",
    "PostByOrgByRepoBranchBody",
    "PostByOrgByRepoBranchResponse201",
    "PostByOrgByRepoBranchResponse400",
    "PostByOrgByRepoBranchResponse400Error",
    "PostByOrgByRepoBranchResponse400ErrorDetails",
    "PostByOrgByRepoBranchResponse401",
    "PostByOrgByRepoBranchResponse401Error",
    "PostByOrgByRepoBranchResponse401ErrorDetails",
    "PostByOrgByRepoBranchResponse403",
    "PostByOrgByRepoBranchResponse403Error",
    "PostByOrgByRepoBranchResponse403ErrorDetails",
    "PostByOrgByRepoBranchResponse404",
    "PostByOrgByRepoBranchResponse404Error",
    "PostByOrgByRepoBranchResponse404ErrorDetails",
    "PostByOrgByRepoBranchResponse406",
    "PostByOrgByRepoBranchResponse406Error",
    "PostByOrgByRepoBranchResponse406ErrorDetails",
    "PostByOrgByRepoBranchResponse409",
    "PostByOrgByRepoBranchResponse409Error",
    "PostByOrgByRepoBranchResponse409ErrorDetails",
    "PostByOrgByRepoBranchResponse500",
    "PostByOrgByRepoBranchResponse500Error",
    "PostByOrgByRepoBranchResponse500ErrorDetails",
    "PostByOrgByRepoCommitBody",
    "PostByOrgByRepoCommitBodyAuthor",
    "PostByOrgByRepoCommitBodyCommitter",
    "PostByOrgByRepoCommitBodyFilesItemType0",
    "PostByOrgByRepoCommitBodyFilesItemType0Encoding",
    "PostByOrgByRepoCommitBodyFilesItemType0Mode",
    "PostByOrgByRepoCommitBodyFilesItemType1",
    "PostByOrgByRepoCommitResponse201",
    "PostByOrgByRepoCommitResponse400",
    "PostByOrgByRepoCommitResponse400Error",
    "PostByOrgByRepoCommitResponse400ErrorDetails",
    "PostByOrgByRepoCommitResponse401",
    "PostByOrgByRepoCommitResponse401Error",
    "PostByOrgByRepoCommitResponse401ErrorDetails",
    "PostByOrgByRepoCommitResponse403",
    "PostByOrgByRepoCommitResponse403Error",
    "PostByOrgByRepoCommitResponse403ErrorDetails",
    "PostByOrgByRepoCommitResponse404",
    "PostByOrgByRepoCommitResponse404Error",
    "PostByOrgByRepoCommitResponse404ErrorDetails",
    "PostByOrgByRepoCommitResponse406",
    "PostByOrgByRepoCommitResponse406Error",
    "PostByOrgByRepoCommitResponse406ErrorDetails",
    "PostByOrgByRepoCommitResponse409",
    "PostByOrgByRepoCommitResponse409Error",
    "PostByOrgByRepoCommitResponse409ErrorDetails",
    "PostByOrgByRepoCommitResponse500",
    "PostByOrgByRepoCommitResponse500Error",
    "PostByOrgByRepoCommitResponse500ErrorDetails",
    "PostByOrgByRepoWebhookBody",
    "PostByOrgByRepoWebhookBodyEventsItem",
    "PostByOrgByRepoWebhookResponse201",
    "PostByOrgByRepoWebhookResponse201EventsItem",
    "PostByOrgByRepoWebhookResponse400",
    "PostByOrgByRepoWebhookResponse400Error",
    "PostByOrgByRepoWebhookResponse400ErrorDetails",
    "PostByOrgByRepoWebhookResponse401",
    "PostByOrgByRepoWebhookResponse401Error",
    "PostByOrgByRepoWebhookResponse401ErrorDetails",
    "PostByOrgByRepoWebhookResponse403",
    "PostByOrgByRepoWebhookResponse403Error",
    "PostByOrgByRepoWebhookResponse403ErrorDetails",
    "PostByOrgByRepoWebhookResponse404",
    "PostByOrgByRepoWebhookResponse404Error",
    "PostByOrgByRepoWebhookResponse404ErrorDetails",
    "PostByOrgByRepoWebhookResponse406",
    "PostByOrgByRepoWebhookResponse406Error",
    "PostByOrgByRepoWebhookResponse406ErrorDetails",
    "PostByOrgByRepoWebhookResponse409",
    "PostByOrgByRepoWebhookResponse409Error",
    "PostByOrgByRepoWebhookResponse409ErrorDetails",
    "PostByOrgByRepoWebhookResponse500",
    "PostByOrgByRepoWebhookResponse500Error",
    "PostByOrgByRepoWebhookResponse500ErrorDetails",
    "PostByOrgRepoBody",
    "PostByOrgRepoBodyTags",
    "PostByOrgRepoBodyUpstream",
    "PostByOrgRepoBodyUpstreamAutosyncType0",
    "PostByOrgRepoBodyUpstreamAutosyncType0ResolutionStrategy",
    "PostByOrgRepoBulkTagsBody",
    "PostByOrgRepoBulkTagsBodyAction",
    "PostByOrgRepoBulkTagsResponse200",
    "PostByOrgRepoBulkTagsResponse400",
    "PostByOrgRepoBulkTagsResponse400Error",
    "PostByOrgRepoBulkTagsResponse400ErrorDetails",
    "PostByOrgRepoBulkTagsResponse401",
    "PostByOrgRepoBulkTagsResponse401Error",
    "PostByOrgRepoBulkTagsResponse401ErrorDetails",
    "PostByOrgRepoBulkTagsResponse403",
    "PostByOrgRepoBulkTagsResponse403Error",
    "PostByOrgRepoBulkTagsResponse403ErrorDetails",
    "PostByOrgRepoBulkTagsResponse404",
    "PostByOrgRepoBulkTagsResponse404Error",
    "PostByOrgRepoBulkTagsResponse404ErrorDetails",
    "PostByOrgRepoBulkTagsResponse406",
    "PostByOrgRepoBulkTagsResponse406Error",
    "PostByOrgRepoBulkTagsResponse406ErrorDetails",
    "PostByOrgRepoBulkTagsResponse409",
    "PostByOrgRepoBulkTagsResponse409Error",
    "PostByOrgRepoBulkTagsResponse409ErrorDetails",
    "PostByOrgRepoBulkTagsResponse500",
    "PostByOrgRepoBulkTagsResponse500Error",
    "PostByOrgRepoBulkTagsResponse500ErrorDetails",
    "PostByOrgRepoResponse201",
    "PostByOrgRepoResponse201Tags",
    "PostByOrgRepoResponse201UpstreamType0",
    "PostByOrgRepoResponse201UpstreamType0AutosyncType0",
    "PostByOrgRepoResponse201UpstreamType0AutosyncType0ResolutionStrategy",
    "PostByOrgRepoResponse400",
    "PostByOrgRepoResponse400Error",
    "PostByOrgRepoResponse400ErrorDetails",
    "PostByOrgRepoResponse401",
    "PostByOrgRepoResponse401Error",
    "PostByOrgRepoResponse401ErrorDetails",
    "PostByOrgRepoResponse403",
    "PostByOrgRepoResponse403Error",
    "PostByOrgRepoResponse403ErrorDetails",
    "PostByOrgRepoResponse404",
    "PostByOrgRepoResponse404Error",
    "PostByOrgRepoResponse404ErrorDetails",
    "PostByOrgRepoResponse406",
    "PostByOrgRepoResponse406Error",
    "PostByOrgRepoResponse406ErrorDetails",
    "PostByOrgRepoResponse409",
    "PostByOrgRepoResponse409Error",
    "PostByOrgRepoResponse409ErrorDetails",
    "PostByOrgRepoResponse500",
    "PostByOrgRepoResponse500Error",
    "PostByOrgRepoResponse500ErrorDetails",
)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.post_by_org_api_key_body_scopes_item import PostByOrgApiKeyBodyScopesItem
from ..types import UNSET, Unset
from typing import cast






T = TypeVar("T", bound="PostByOrgApiKeyBody")



@_attrs_define
class PostByOrgApiKeyBody:
    """ 
        Attributes:
            name (str | Unset):
            scopes (list[PostByOrgApiKeyBodyScopesItem] | Unset):
            repo_ids (list[str] | Unset):
     """

    name: str | Unset = UNSET
    scopes: list[PostByOrgApiKeyBodyScopesItem] | Unset = UNSET
    repo_ids: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        name = self.name

        scopes: list[str] | Unset = UNSET
        if not isinstance(self.scopes, Unset):
            scopes = []
            for scopes_item_data in self.scopes:
                scopes_item = scopes_item_data.value
                scopes.append(scopes_item)



        repo_ids: list[str] | Unset = UNSET
        if not isinstance(self.repo_ids, Unset):
            repo_ids = self.repo_ids




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if name is not UNSET:
            field_dict["name"] = name
        if scopes is not UNSET:
            field_dict["scopes"] = scopes
        if repo_ids is not UNSET:
            field_dict["repo_ids"] = repo_ids

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name", UNSET)

        _scopes = d.pop("scopes", UNSET)
        scopes: list[PostByOrgApiKeyBodyScopesItem] | Unset = UNSET
        if _scopes is not UNSET:
            scopes = []
            for scopes_item_data in _scopes:
                scopes_item = PostByOrgApiKeyBodyScopesItem(scopes_item_data)



                scopes.append(scopes_item)


        repo_ids = cast(list[str], d.pop("repo_ids", UNSET))


        post_by_org_api_key_body = cls(
            name=name,
            scopes=scopes,
            repo_ids=repo_ids,
        )


        post_by_org_api_key_body.additional_properties = d
        return post_by_org_api_key_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.get_by_org_repo_response_200 import GetByOrgRepoResponse200
from ...models.get_by_org_repo_response_400 import GetByOrgRepoResponse400
from ...models.get_by_org_repo_response_401 import GetByOrgRepoResponse401
from ...models.get_by_org_repo_response_403 import GetByOrgRepoResponse403
from ...models.get_by_org_repo_response_404 import GetByOrgRepoResponse404
from ...models.get_by_org_repo_response_406 import GetByOrgRepoResponse406
from ...models.get_by_org_repo_response_409 import GetByOrgRepoResponse409
from ...models.get_by_org_repo_response_500 import GetByOrgRepoResponse500
from ...types import UNSET, Unset
from typing import cast



def _get_kwargs(
    org: str,
    *,
    cursor: str | Unset = UNSET,
    limit: int | Unset = UNSET,
    tags: str | Unset = UNSET,

) -> dict[str, Any]:
    

    

    params: dict[str, Any] = {}

    params["cursor"] = cursor

    params["limit"] = limit

    params["tags"] = tags


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/{org}/repo".format(org=quote(str(org), safe=""),),
        "params": params,
    }


    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500 | None:
    if response.status_code == 200:
        response_200 = GetByOrgRepoResponse200.from_dict(response.json())



        return response_200

    if response.status_code == 400:
        response_400 = GetByOrgRepoResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = GetByOrgRepoResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 403:
        response_403 = GetByOrgRepoResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = GetByOrgRepoResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 406:
        response_406 = GetByOrgRepoResponse406.from_dict(response.json())



        return response_406

    if response.status_code == 409:
        response_409 = GetByOrgRepoResponse409.from_dict(response.json())



        return response_409

    if response.status_code == 500:
        response_500 = GetByOrgRepoResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    cursor: str | Unset = UNSET,
    limit: int | Unset = UNSET,
    tags: str | Unset = UNSET,

) -> Response[GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500]:
    """ List repositories

     List repositories in the organization using cursor pagination

    Args:
        org (str):
        cursor (str | Unset):
        limit (int | Unset):
        tags (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
cursor=cursor,
limit=limit,
tags=tags,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    cursor: str | Unset = UNSET,
    limit: int | Unset = UNSET,
    tags: str | Unset = UNSET,

) -> GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500 | None:
    """ List repositories

     List repositories in the organization using cursor pagination

    Args:
        org (str):
        cursor (str | Unset):
        limit (int | Unset):
        tags (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500
     """


    return sync_detailed(
        org=org,
client=client,
cursor=cursor,
limit=limit,
tags=tags,

    ).parsed

async def asyncio_detailed(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    cursor: str | Unset = UNSET,
    limit: int | Unset = UNSET,
    tags: str | Unset = UNSET,

) -> Response[GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500]:
    """ List repositories

     List repositories in the organization using cursor pagination

    Args:
        org (str):
        cursor (str | Unset):
        limit (int | Unset):
        tags (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
cursor=cursor,
limit=limit,
tags=tags,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    cursor: str | Unset = UNSET,
    limit: int | Unset = UNSET,
    tags: str | Unset = UNSET,

) -> GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500 | None:
    """ List repositories

     List repositories in the organization using cursor pagination

    Args:
        org (str):
        cursor (str | Unset):
        limit (int | Unset):
        tags (str | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgRepoResponse200 | GetByOrgRepoResponse400 | GetByOrgRepoResponse401 | GetByOrgRepoResponse403 | GetByOrgRepoResponse404 | GetByOrgRepoResponse406 | GetByOrgRepoResponse409 | GetByOrgRepoResponse500
     """


    return (await asyncio_detailed(
        org=org,
client=client,
cursor=cursor,
limit=limit,
tags=tags,

    )).parsed



from enum import Enum

class GetByOrgByRepoDiffResponse200FilteredFilesItemStatus(str, Enum):
    A = "A"
    C = "C"
    D = "D"
    M = "M"
    R = "R"
    T = "T"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.post_by_org_api_key_body import PostByOrgApiKeyBody
from ...models.post_by_org_api_key_response_201 import PostByOrgApiKeyResponse201
from ...models.post_by_org_api_key_response_400 import PostByOrgApiKeyResponse400
from ...models.post_by_org_api_key_response_401 import PostByOrgApiKeyResponse401
from ...models.post_by_org_api_key_response_403 import PostByOrgApiKeyResponse403
from ...models.post_by_org_api_key_response_404 import PostByOrgApiKeyResponse404
from ...models.post_by_org_api_key_response_406 import PostByOrgApiKeyResponse406
from ...models.post_by_org_api_key_response_409 import PostByOrgApiKeyResponse409
from ...models.post_by_org_api_key_response_500 import PostByOrgApiKeyResponse500
from typing import cast



def _get_kwargs(
    org: str,
    *,
    body: PostByOrgApiKeyBody,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/{org}/api-key".format(org=quote(str(org), safe=""),),
    }

    _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500 | None:
    if response.status_code == 201:
        response_201 = PostByOrgApiKeyResponse201.from_dict(response.json())



        return response_201

    if response.status_code == 400:
        response_400 = PostByOrgApiKeyResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = PostByOrgApiKeyResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 403:
        response_403 = PostByOrgApiKeyResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = PostByOrgApiKeyResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 406:
        response_406 = PostByOrgApiKeyResponse406.from_dict(response.json())



        return response_406

    if response.status_code == 409:
        response_409 = PostByOrgApiKeyResponse409.from_dict(response.json())



        return response_409

    if response.status_code == 500:
        response_500 = PostByOrgApiKeyResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgApiKeyBody,

) -> Response[PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500]:
    """ Create API key

     Create a new API key for programmatic access

    Args:
        org (str):
        body (PostByOrgApiKeyBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgApiKeyBody,

) -> PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500 | None:
    """ Create API key

     Create a new API key for programmatic access

    Args:
        org (str):
        body (PostByOrgApiKeyBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500
     """


    return sync_detailed(
        org=org,
client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgApiKeyBody,

) -> Response[PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500]:
    """ Create API key

     Create a new API key for programmatic access

    Args:
        org (str):
        body (PostByOrgApiKeyBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgApiKeyBody,

) -> PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500 | None:
    """ Create API key

     Create a new API key for programmatic access

    Args:
        org (str):
        body (PostByOrgApiKeyBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PostByOrgApiKeyResponse201 | PostByOrgApiKeyResponse400 | PostByOrgApiKeyResponse401 | PostByOrgApiKeyResponse403 | PostByOrgApiKeyResponse404 | PostByOrgApiKeyResponse406 | PostByOrgApiKeyResponse409 | PostByOrgApiKeyResponse500
     """


    return (await asyncio_detailed(
        org=org,
client=client,
body=body,

    )).parsed



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.get_by_org_by_repo_webhook_response_200 import GetByOrgByRepoWebhookResponse200
from ...models.get_by_org_by_repo_webhook_response_400 import GetByOrgByRepoWebhookResponse400
from ...models.get_by_org_by_repo_webhook_response_401 import GetByOrgByRepoWebhookResponse401
from ...models.get_by_org_by_repo_webhook_response_403 import GetByOrgByRepoWebhookResponse403
from ...models.get_by_org_by_repo_webhook_response_404 import GetByOrgByRepoWebhookResponse404
from ...models.get_by_org_by_repo_webhook_response_406 import GetByOrgByRepoWebhookResponse406
from ...models.get_by_org_by_repo_webhook_response_409 import GetByOrgByRepoWebhookResponse409
from ...models.get_by_org_by_repo_webhook_response_500 import GetByOrgByRepoWebhookResponse500
from typing import cast



def _get_kwargs(
    org: str,
    repo: str,

) -> dict[str, Any]:
    

    

    

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/{org}/{repo}/webhook".format(org=quote(str(org), safe=""),repo=quote(str(repo), safe=""),),
    }


    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500 | None:
    if response.status_code == 200:
        response_200 = GetByOrgByRepoWebhookResponse200.from_dict(response.json())



        return response_200

    if response.status_code == 400:
        response_400 = GetByOrgByRepoWebhookResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = GetByOrgByRepoWebhookResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 403:
        response_403 = GetByOrgByRepoWebhookResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = GetByOrgByRepoWebhookResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 406:
        response_406 = GetByOrgByRepoWebhookResponse406.from_dict(response.json())



        return response_406

    if response.status_code == 409:
        response_409 = GetByOrgByRepoWebhookResponse409.from_dict(response.json())



        return response_409

    if response.status_code == 500:
        response_500 = GetByOrgByRepoWebhookResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,

) -> Response[GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500]:
    """ List webhooks

     List webhooks for a repository

    Args:
        org (str):
        repo (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,

) -> GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500 | None:
    """ List webhooks

     List webhooks for a repository

    Args:
        org (str):
        repo (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500
     """


    return sync_detailed(
        org=org,
repo=repo,
client=client,

    ).parsed

async def asyncio_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,

) -> Response[GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500]:
    """ List webhooks

     List webhooks for a repository

    Args:
        org (str):
        repo (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,

) -> GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500 | None:
    """ List webhooks

     List webhooks for a repository

    Args:
        org (str):
        repo (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgByRepoWebhookResponse200 | GetByOrgByRepoWebhookResponse400 | GetByOrgByRepoWebhookResponse401 | GetByOrgByRepoWebhookResponse403 | GetByOrgByRepoWebhookResponse404 | GetByOrgByRepoWebhookResponse406 | GetByOrgByRepoWebhookResponse409 | GetByOrgByRepoWebhookResponse500
     """


    return (await asyncio_detailed(
        org=org,
repo=repo,
client=client,

    )).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.patch_by_org_by_repo_body_upstream_type_0_autosync_type_0 import PatchByOrgByRepoBodyUpstreamType0AutosyncType0





T = TypeVar("T", bound="PatchByOrgByRepoBodyUpstreamType0")



@_attrs_define
class PatchByOrgByRepoBodyUpstreamType0:
    """ 
        Attributes:
            uri (str): URL of the upstream repository
            autosync (PatchByOrgByRepoBodyUpstreamType0AutosyncType0 | Unset): Optionally enable automatic sync from the
                upstream repository
            token (None | str | Unset): Personal access token for private upstream repos. Set to null to unlink credential.
            token_username (str | Unset): Username for git credential auth. Defaults to "x-access-token". Use actual
                username for Bitbucket app passwords.
     """

    uri: str
    autosync: PatchByOrgByRepoBodyUpstreamType0AutosyncType0 | Unset = UNSET
    token: None | str | Unset = UNSET
    token_username: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.patch_by_org_by_repo_body_upstream_type_0_autosync_type_0 import PatchByOrgByRepoBodyUpstreamType0AutosyncType0
        uri = self.uri

        autosync: dict[str, Any] | Unset
        if isinstance(self.autosync, Unset):
            autosync = UNSET
        else:
            autosync = self.autosync.to_dict()


        token: None | str | Unset
        if isinstance(self.token, Unset):
            token = UNSET
        else:
            token = self.token

        token_username = self.token_username


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "uri": uri,
        })
        if autosync is not UNSET:
            field_dict["autosync"] = autosync
        if token is not UNSET:
            field_dict["token"] = token
        if token_username is not UNSET:
            field_dict["token_username"] = token_username

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.patch_by_org_by_repo_body_upstream_type_0_autosync_type_0 import PatchByOrgByRepoBodyUpstreamType0AutosyncType0
        d = dict(src_dict)
        uri = d.pop("uri")

        def _parse_autosync(data: object) -> PatchByOrgByRepoBodyUpstreamType0AutosyncType0 | Unset:
            if isinstance(data, Unset):
                return data
            if not isinstance(data, dict):
                raise TypeError()
            autosync_type_0 = PatchByOrgByRepoBodyUpstreamType0AutosyncType0.from_dict(data)



            return autosync_type_0

        autosync = _parse_autosync(d.pop("autosync", UNSET))


        def _parse_token(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        token = _parse_token(d.pop("token", UNSET))


        token_username = d.pop("token_username", UNSET)

        patch_by_org_by_repo_body_upstream_type_0 = cls(
            uri=uri,
            autosync=autosync,
            token=token,
            token_username=token_username,
        )


        patch_by_org_by_repo_body_upstream_type_0.additional_properties = d
        return patch_by_org_by_repo_body_upstream_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="GetWhoamiResponse200Org")



@_attrs_define
class GetWhoamiResponse200Org:
    """ 
        Attributes:
            id (str):
            slug (str):
            name (str):
     """

    id: str
    slug: str
    name: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        id = self.id

        slug = self.slug

        name = self.name


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "id": id,
            "slug": slug,
            "name": name,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        slug = d.pop("slug")

        name = d.pop("name")

        get_whoami_response_200_org = cls(
            id=id,
            slug=slug,
            name=name,
        )


        get_whoami_response_200_org.additional_properties = d
        return get_whoami_response_200_org

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_whoami_response_200_org import GetWhoamiResponse200Org





T = TypeVar("T", bound="GetWhoamiResponse200")



@_attrs_define
class GetWhoamiResponse200:
    """ 
        Attributes:
            org (GetWhoamiResponse200Org):
            key_id (None | str):
            key_name (None | str):
            scopes (list[str]):
     """

    org: GetWhoamiResponse200Org
    key_id: None | str
    key_name: None | str
    scopes: list[str]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_whoami_response_200_org import GetWhoamiResponse200Org
        org = self.org.to_dict()

        key_id: None | str
        key_id = self.key_id

        key_name: None | str
        key_name = self.key_name

        scopes = self.scopes




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "org": org,
            "key_id": key_id,
            "key_name": key_name,
            "scopes": scopes,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_whoami_response_200_org import GetWhoamiResponse200Org
        d = dict(src_dict)
        org = GetWhoamiResponse200Org.from_dict(d.pop("org"))




        def _parse_key_id(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        key_id = _parse_key_id(d.pop("key_id"))


        def _parse_key_name(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        key_name = _parse_key_name(d.pop("key_name"))


        scopes = cast(list[str], d.pop("scopes"))


        get_whoami_response_200 = cls(
            org=org,
            key_id=key_id,
            key_name=key_name,
            scopes=scopes,
        )


        get_whoami_response_200.additional_properties = d
        return get_whoami_response_200

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.patch_by_org_by_repo_body_tags import PatchByOrgByRepoBodyTags
  from ..models.patch_by_org_by_repo_body_upstream_type_0 import PatchByOrgByRepoBodyUpstreamType0





T = TypeVar("T", bound="PatchByOrgByRepoBody")



@_attrs_define
class PatchByOrgByRepoBody:
    """ 
        Attributes:
            name (str | Unset):
            default_branch (str | Unset):
            tags (PatchByOrgByRepoBodyTags | Unset):
            upstream (None | PatchByOrgByRepoBodyUpstreamType0 | Unset):
     """

    name: str | Unset = UNSET
    default_branch: str | Unset = UNSET
    tags: PatchByOrgByRepoBodyTags | Unset = UNSET
    upstream: None | PatchByOrgByRepoBodyUpstreamType0 | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.patch_by_org_by_repo_body_upstream_type_0 import PatchByOrgByRepoBodyUpstreamType0
        from ..models.patch_by_org_by_repo_body_tags import PatchByOrgByRepoBodyTags
        name = self.name

        default_branch = self.default_branch

        tags: dict[str, Any] | Unset = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        upstream: dict[str, Any] | None | Unset
        if isinstance(self.upstream, Unset):
            upstream = UNSET
        elif isinstance(self.upstream, PatchByOrgByRepoBodyUpstreamType0):
            upstream = self.upstream.to_dict()
        else:
            upstream = self.upstream


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if name is not UNSET:
            field_dict["name"] = name
        if default_branch is not UNSET:
            field_dict["default_branch"] = default_branch
        if tags is not UNSET:
            field_dict["tags"] = tags
        if upstream is not UNSET:
            field_dict["upstream"] = upstream

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.patch_by_org_by_repo_body_tags import PatchByOrgByRepoBodyTags
        from ..models.patch_by_org_by_repo_body_upstream_type_0 import PatchByOrgByRepoBodyUpstreamType0
        d = dict(src_dict)
        name = d.pop("name", UNSET)

        default_branch = d.pop("default_branch", UNSET)

        _tags = d.pop("tags", UNSET)
        tags: PatchByOrgByRepoBodyTags | Unset
        if isinstance(_tags,  Unset):
            tags = UNSET
        else:
            tags = PatchByOrgByRepoBodyTags.from_dict(_tags)




        def _parse_upstream(data: object) -> None | PatchByOrgByRepoBodyUpstreamType0 | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                upstream_type_0 = PatchByOrgByRepoBodyUpstreamType0.from_dict(data)



                return upstream_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | PatchByOrgByRepoBodyUpstreamType0 | Unset, data)

        upstream = _parse_upstream(d.pop("upstream", UNSET))


        patch_by_org_by_repo_body = cls(
            name=name,
            default_branch=default_branch,
            tags=tags,
            upstream=upstream,
        )


        patch_by_org_by_repo_body.additional_properties = d
        return patch_by_org_by_repo_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.get_by_org_by_repo_commit_response_200_commits_item_author import GetByOrgByRepoCommitResponse200CommitsItemAuthor
  from ..models.get_by_org_by_repo_commit_response_200_commits_item_committer import GetByOrgByRepoCommitResponse200CommitsItemCommitter





T = TypeVar("T", bound="GetByOrgByRepoCommitResponse200CommitsItem")



@_attrs_define
class GetByOrgByRepoCommitResponse200CommitsItem:
    """ 
        Attributes:
            sha (str):
            message (str):
            author (GetByOrgByRepoCommitResponse200CommitsItemAuthor):
            committer (GetByOrgByRepoCommitResponse200CommitsItemCommitter):
            parents (list[str] | Unset):
     """

    sha: str
    message: str
    author: GetByOrgByRepoCommitResponse200CommitsItemAuthor
    committer: GetByOrgByRepoCommitResponse200CommitsItemCommitter
    parents: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_by_org_by_repo_commit_response_200_commits_item_committer import GetByOrgByRepoCommitResponse200CommitsItemCommitter
        from ..models.get_by_org_by_repo_commit_response_200_commits_item_author import GetByOrgByRepoCommitResponse200CommitsItemAuthor
        sha = self.sha

        message = self.message

        author = self.author.to_dict()

        committer = self.committer.to_dict()

        parents: list[str] | Unset = UNSET
        if not isinstance(self.parents, Unset):
            parents = self.parents




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "sha": sha,
            "message": message,
            "author": author,
            "committer": committer,
        })
        if parents is not UNSET:
            field_dict["parents"] = parents

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_by_org_by_repo_commit_response_200_commits_item_author import GetByOrgByRepoCommitResponse200CommitsItemAuthor
        from ..models.get_by_org_by_repo_commit_response_200_commits_item_committer import GetByOrgByRepoCommitResponse200CommitsItemCommitter
        d = dict(src_dict)
        sha = d.pop("sha")

        message = d.pop("message")

        author = GetByOrgByRepoCommitResponse200CommitsItemAuthor.from_dict(d.pop("author"))




        committer = GetByOrgByRepoCommitResponse200CommitsItemCommitter.from_dict(d.pop("committer"))




        parents = cast(list[str], d.pop("parents", UNSET))


        get_by_org_by_repo_commit_response_200_commits_item = cls(
            sha=sha,
            message=message,
            author=author,
            committer=committer,
            parents=parents,
        )


        get_by_org_by_repo_commit_response_200_commits_item.additional_properties = d
        return get_by_org_by_repo_commit_response_200_commits_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0_resolution_strategy import GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0ResolutionStrategy
from typing import Literal, cast






T = TypeVar("T", bound="GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0")



@_attrs_define
class GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0:
    """ 
        Attributes:
            type_ (Literal['poll']):
            period (float): Polling period in seconds
            resolution_strategy (GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0ResolutionStrategy): Conflict
                resolution strategy. "none" means sync will fail on conflicts.
     """

    type_: Literal['poll']
    period: float
    resolution_strategy: GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0ResolutionStrategy
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        period = self.period

        resolution_strategy = self.resolution_strategy.value


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "period": period,
            "resolution_strategy": resolution_strategy,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['poll'] , d.pop("type"))
        if type_ != 'poll':
            raise ValueError(f"type must match const 'poll', got '{type_}'")

        period = d.pop("period")

        resolution_strategy = GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0ResolutionStrategy(d.pop("resolution_strategy"))




        get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0 = cls(
            type_=type_,
            period=period,
            resolution_strategy=resolution_strategy,
        )


        get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0.additional_properties = d
        return get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.get_by_org_by_repo_diff_response_200_files_item_status import GetByOrgByRepoDiffResponse200FilesItemStatus
from ..types import UNSET, Unset






T = TypeVar("T", bound="GetByOrgByRepoDiffResponse200FilesItem")



@_attrs_define
class GetByOrgByRepoDiffResponse200FilesItem:
    """ 
        Attributes:
            path (str):
            status (GetByOrgByRepoDiffResponse200FilesItemStatus):
            old_path (str | Unset):
            bytes_ (float | Unset):
            is_eof (bool | Unset):
            raw (str | Unset):
     """

    path: str
    status: GetByOrgByRepoDiffResponse200FilesItemStatus
    old_path: str | Unset = UNSET
    bytes_: float | Unset = UNSET
    is_eof: bool | Unset = UNSET
    raw: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        path = self.path

        status = self.status.value

        old_path = self.old_path

        bytes_ = self.bytes_

        is_eof = self.is_eof

        raw = self.raw


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "path": path,
            "status": status,
        })
        if old_path is not UNSET:
            field_dict["old_path"] = old_path
        if bytes_ is not UNSET:
            field_dict["bytes"] = bytes_
        if is_eof is not UNSET:
            field_dict["is_eof"] = is_eof
        if raw is not UNSET:
            field_dict["raw"] = raw

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        path = d.pop("path")

        status = GetByOrgByRepoDiffResponse200FilesItemStatus(d.pop("status"))




        old_path = d.pop("old_path", UNSET)

        bytes_ = d.pop("bytes", UNSET)

        is_eof = d.pop("is_eof", UNSET)

        raw = d.pop("raw", UNSET)

        get_by_org_by_repo_diff_response_200_files_item = cls(
            path=path,
            status=status,
            old_path=old_path,
            bytes_=bytes_,
            is_eof=is_eof,
            raw=raw,
        )


        get_by_org_by_repo_diff_response_200_files_item.additional_properties = d
        return get_by_org_by_repo_diff_response_200_files_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
